@@ -63,59 +63,49 @@ class DemuxComp(ExplicitComponent):
         """
         self._vars[name] = {'val': val, 'shape': shape, 'units': units, 'desc': desc, 'axis': axis}
 
-    def _post_configure(self):
-        """
-        Declare inputs, outputs, and derivatives for the demux component.
-        """
-        # set static mode to False because we are doing things that would normally be done in setup
-        self._static_mode = False
-
         opts = self.options
         vec_size = opts['vec_size']
 
-        for var, options in self._vars.items():
-            kwgs = dict(options)
-            shape = options['shape']
-            size = np.prod(shape)
-            axis = kwgs.pop('axis')
+        # for var, options in self._vars.items():
+        options = self._vars[name]
+        kwgs = dict(options)
+        shape = options['shape']
+        size = np.prod(shape)
+        axis = kwgs.pop('axis')
 
-            if axis >= len(shape):
-                raise RuntimeError("{}: Invalid axis ({}) for variable '{}' of "
-                                   "shape {}".format(self.msginfo, axis, var, shape))
+        if axis >= len(shape):
+            raise RuntimeError("{}: Invalid axis ({}) for variable '{}' of "
+                               "shape {}".format(self.msginfo, axis, name, shape))
 
-            if shape[axis] != vec_size:
-                raise RuntimeError("{}: Variable '{}' cannot be demuxed along axis {}. Axis size "
-                                   "is {} but vec_size is {}.".format(self.msginfo, var, axis,
-                                                                      shape[axis], vec_size))
+        if shape[axis] != vec_size:
+            raise RuntimeError("{}: Variable '{}' cannot be demuxed along axis {}. Axis size "
+                               "is {} but vec_size is {}.".format(self.msginfo, name, axis,
+                                                                  shape[axis], vec_size))
 
-            self.add_input(var, **kwgs)
+        self.add_input(name, **kwgs)
 
-            template = np.reshape(np.arange(size), shape)
+        template = np.reshape(np.arange(size), shape)
 
-            self._output_names[var] = []
+        self._output_names[name] = []
 
-            out_shape = list(shape)
-            out_shape.pop(axis)
-            if len(out_shape) == 0:
-                out_shape = [1]
+        out_shape = list(shape)
+        out_shape.pop(axis)
+        if len(out_shape) == 0:
+            out_shape = [1]
 
-            for i in range(vec_size):
-                out_name = '{0}_{1}'.format(var, i)
-                self._output_names[var].append(out_name)
-                self.add_output(name=out_name,
-                                val=options['val'],
-                                shape=out_shape,
-                                units=options['units'],
-                                desc=options['desc'])
+        for i in range(vec_size):
+            out_name = '{0}_{1}'.format(name, i)
+            self._output_names[name].append(out_name)
+            self.add_output(name=out_name,
+                            val=options['val'],
+                            shape=out_shape,
+                            units=options['units'],
+                            desc=options['desc'])
 
-                rs = np.arange(np.prod(out_shape))
-                cs = np.atleast_1d(np.take(template, indices=i, axis=axis))
+            rs = np.arange(np.prod(out_shape))
+            cs = np.atleast_1d(np.take(template, indices=i, axis=axis))
 
-                self.declare_partials(of=out_name, wrt=var, rows=rs, cols=cs, val=1.0)
-
-        self._static_mode = True
-
-        super(DemuxComp, self)._post_configure()
+            self.declare_partials(of=out_name, wrt=name, rows=rs, cols=cs, val=1.0)
 
     def compute(self, inputs, outputs):
         """
