@@ -1,6 +1,4 @@
 """Define the ExternalCodeComp and ExternalCodeImplicitComp classes."""
-from __future__ import print_function
-
 import os
 import sys
 import re
@@ -12,7 +10,6 @@ from openmdao.core.analysis_error import AnalysisError
 from openmdao.core.explicitcomponent import ExplicitComponent
 from openmdao.core.implicitcomponent import ImplicitComponent
 from openmdao.utils.shell_proc import STDOUT, DEV_NULL, ShellProc
-from openmdao.utils.general_utils import warn_deprecation
 
 
 class ExternalCodeDelegate(object):
@@ -312,27 +309,6 @@ class ExternalCodeComp(ExplicitComponent):
         self._external_code_runner.run_component()
 
 
-class ExternalCode(ExternalCodeComp):
-    """
-    Deprecated.
-    """
-
-    def __init__(self, *args, **kwargs):
-        """
-        Capture Initialize to throw warning.
-
-        Parameters
-        ----------
-        *args : list
-            Deprecated arguments.
-        **kwargs : dict
-            Deprecated arguments.
-        """
-        warn_deprecation("'ExternalCode' has been deprecated. Use "
-                         "'ExternalCodeComp' instead.")
-        super(ExternalCode, self).__init__(*args, **kwargs)
-
-
 class ExternalCodeImplicitComp(ImplicitComponent):
     """
     Run an external code as a component.
