@@ -6,7 +6,7 @@ from numpy.testing import assert_almost_equal
 
 import openmdao.api as om
 from openmdao.test_suite.components.sellar_feature import SellarIDF
-from openmdao.utils.assert_utils import assert_rel_error, assert_check_partials
+from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials
 
 
 class TestEQConstraintComp(unittest.TestCase):
@@ -24,18 +24,15 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
         # check results
         prob.run_driver()
 
-        assert_rel_error(self, prob['dv.x'], 0., 1e-5)
-        assert_rel_error(self, prob['dv.z'], [1.977639, 0.], 1e-5)
+        assert_near_equal(prob['dv.x'], 0., 1e-5)
+        assert_near_equal(prob['dv.z'], [1.977639, 0.], 1e-5)
 
-        assert_rel_error(self, prob['obj_cmp.obj'], 3.18339395045, 1e-5)
+        assert_near_equal(prob['obj_cmp.obj'], 3.18339395045, 1e-5)
 
         assert_almost_equal(prob['dv.y1'], 3.16)
         assert_almost_equal(prob['d1.y1'], 3.16)
@@ -88,9 +85,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_create_on_init_add_constraint(self):
@@ -128,9 +122,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_create_on_init_add_constraint_no_normalization(self):
@@ -163,7 +154,7 @@ class TestEQConstraintComp(unittest.TestCase):
         lhs = prob['f.y']
         rhs = prob['g.y']
         diff = lhs - rhs
-        assert_rel_error(self, prob['equal.y'], diff)
+        assert_near_equal(prob['equal.y'], diff)
 
         prob.driver = om.ScipyOptimizeDriver(disp=False)
 
@@ -176,9 +167,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized(self):
@@ -216,9 +204,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_set_shape(self):
@@ -256,9 +241,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_no_normalization(self):
@@ -293,7 +275,7 @@ class TestEQConstraintComp(unittest.TestCase):
         lhs = prob['f.y']
         rhs = prob['g.y']
         diff = lhs - rhs
-        assert_rel_error(self, prob['equal.y'], diff)
+        assert_near_equal(prob['equal.y'], diff)
 
         prob.run_driver()
 
@@ -304,9 +286,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_scalar_with_mult(self):
@@ -333,13 +312,11 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
-        assert_rel_error(self, prob['equal.y'], 0., 1e-6)
-        assert_rel_error(self, prob['indep.x'], 2., 1e-6)
-        assert_rel_error(self, prob['f.y'], 4., 1e-6)
+        assert_near_equal(prob['equal.y'], 0., 1e-6)
+        assert_near_equal(prob['indep.x'], 2., 1e-6)
+        assert_near_equal(prob['f.y'], 4., 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
 
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
@@ -401,13 +378,11 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
-        assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
-        assert_rel_error(self, prob['indep.x'], np.ones(n)*2., 1e-6)
-        assert_rel_error(self, prob['f.y'], np.ones(n)*4., 1e-6)
+        assert_near_equal(prob['equal.y'], np.zeros(n), 1e-6)
+        assert_near_equal(prob['indep.x'], np.ones(n)*2., 1e-6)
+        assert_near_equal(prob['f.y'], np.ones(n)*4., 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
 
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
@@ -437,13 +412,11 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
-        assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
-        assert_rel_error(self, prob['indep.x'], np.ones(n)*2., 1e-6)
-        assert_rel_error(self, prob['f.y'], np.ones(n)*4., 1e-6)
+        assert_near_equal(prob['equal.y'], np.zeros(n), 1e-6)
+        assert_near_equal(prob['indep.x'], np.ones(n)*2., 1e-6)
+        assert_near_equal(prob['f.y'], np.ones(n)*4., 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
 
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
@@ -467,15 +440,12 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
-        assert_rel_error(self, prob['equal.y'], 0., 1e-6)
-        assert_rel_error(self, prob['indep.x'], 2., 1e-6)
-        assert_rel_error(self, prob['f.y'], 4., 1e-6)
+        assert_near_equal(prob['equal.y'], 0., 1e-6)
+        assert_near_equal(prob['indep.x'], 2., 1e-6)
+        assert_near_equal(prob['f.y'], 4., 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_vectorized_rhs_val(self):
@@ -504,13 +474,13 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.driver = om.ScipyOptimizeDriver(disp=False)
         prob.run_driver()
 
-        assert_rel_error(self, prob['equal.y'], np.zeros(n), 1e-6)
-        assert_rel_error(self, prob['indep.x'], np.ones(n)*2., 1e-6)
-        assert_rel_error(self, prob['f.y'], np.ones(n)*4., 1e-6)
+        assert_near_equal(prob['equal.y'], np.zeros(n), 1e-6)
+        assert_near_equal(prob['indep.x'], np.ones(n)*2., 1e-6)
+        assert_near_equal(prob['f.y'], np.ones(n)*4., 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
+
+        assert_check_partials(cpd, atol=2e-5, rtol=2e-5)
 
     def test_specified_shape_rhs_val(self):
         prob = om.Problem()
@@ -529,11 +499,11 @@ class TestEQConstraintComp(unittest.TestCase):
         prob.setup()
         prob.run_model()
 
-        assert_rel_error(self, prob['equal.y'], np.ones(shape) - rhs, 1e-6)
+        assert_near_equal(prob['equal.y'], np.ones(shape) - rhs, 1e-6)
 
         cpd = prob.check_partials(out_stream=None)
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
+
+        assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
     def test_renamed_vars(self):
         prob = om.Problem()
@@ -568,9 +538,6 @@ class TestEQConstraintComp(unittest.TestCase):
 
         cpd = prob.check_partials(out_stream=None)
 
-        for (of, wrt) in cpd['equal']:
-            assert_almost_equal(cpd['equal'][of, wrt]['abs error'], 0.0, decimal=5)
-
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
 
@@ -585,14 +552,14 @@ class TestFeatureEQConstraintComp(unittest.TestCase):
         prob.setup()
         prob.run_driver()
 
-        assert_rel_error(self, prob['dv.x'], 0., 1e-5)
+        assert_near_equal(prob['dv.x'], 0., 1e-5)
 
-        assert_rel_error(self, [prob['dv.y1'], prob['d1.y1']], [[3.16], [3.16]], 1e-5)
-        assert_rel_error(self, [prob['dv.y2'], prob['d2.y2']], [[3.7552778], [3.7552778]], 1e-5)
+        assert_near_equal([prob['dv.y1'], prob['d1.y1']], [[3.16], [3.16]], 1e-5)
+        assert_near_equal([prob['dv.y2'], prob['d2.y2']], [[3.7552778], [3.7552778]], 1e-5)
 
-        assert_rel_error(self, prob['dv.z'], [1.977639, 0.], 1e-5)
+        assert_near_equal(prob['dv.z'], [1.977639, 0.], 1e-5)
 
-        assert_rel_error(self, prob['obj_cmp.obj'], 3.18339395045, 1e-5)
+        assert_near_equal(prob['obj_cmp.obj'], 3.18339395045, 1e-5)
 
 
 if __name__ == '__main__':  # pragma: no cover
