@@ -1,14 +1,10 @@
 """Define a base class for all Drivers in OpenMDAO."""
-from __future__ import print_function
-
 from collections import OrderedDict
 import pprint
 import sys
 import os
 import weakref
 
-from six import iteritems, itervalues, string_types
-
 import numpy as np
 
 from openmdao.core.total_jac import _TotalJacInfo
@@ -19,6 +15,7 @@ from openmdao.utils.general_utils import simple_warning, warn_deprecation
 from openmdao.utils.mpi import MPI
 from openmdao.utils.options_dictionary import OptionsDictionary
 import openmdao.utils.coloring as coloring_mod
+from openmdao.vectors.vector import INT_DTYPE
 
 
 def _check_debug_print_opts_valid(name, opts):
@@ -67,6 +64,9 @@ class Driver(object):
         Contains all design variable info.
     _designvars_discrete : list
         List of design variables that are discrete.
+    _distributed_resp : dict
+        Dict of constraints that are distributed outputs. Key is rank, values are
+        (local indices, local sizes).
     _cons : dict
         Contains all constraint info.
     _objs : dict
@@ -125,7 +125,13 @@ class Driver(object):
         self.recording_options = OptionsDictionary(parent_name=type(self).__name__)
 
         self.recording_options.declare('record_model_metadata', types=bool, default=True,
-                                       desc='Record metadata for all Systems in the model')
+                                       desc='Deprecated. Recording of model metadata will always '
+                                       'be done',
+                                       deprecation="The recording option, record_model_metadata, "
+                                       "on Driver is "
+                                       "deprecated. Recording of model metadata will always "
+                                       "be done",
+                                       )
         self.recording_options.declare('record_desvars', types=bool, default=True,
                                        desc='Set to True to record design variables at the '
                                             'driver level')
@@ -139,8 +145,8 @@ class Driver(object):
                                        desc='Set to True to record constraints at the '
                                             'driver level')
         self.recording_options.declare('includes', types=list, default=[],
-                                       desc='Patterns for variables to include in recording. \
-                                       Uses fnmatch wildcards')
+                                       desc='Patterns for variables to include in recording. '
+                                       'Uses fnmatch wildcards')
         self.recording_options.declare('excludes', types=list, default=[],
                                        desc='Patterns for vars to exclude in recording '
                                             '(processed post-includes). Uses fnmatch wildcards')
@@ -149,6 +155,12 @@ class Driver(object):
                                             'level')
         self.recording_options.declare('record_inputs', types=bool, default=True,
                                        desc='Set to True to record inputs at the driver level')
+        self.recording_options.declare('record_outputs', types=bool, default=True,
+                                       desc='Set True to record outputs at the '
+                                            'driver level.')
+        self.recording_options.declare('record_residuals', types=bool, default=False,
+                                       desc='Set True to record residuals at the '
+                                            'driver level.')
 
         # What the driver supports.
         self.supports = OptionsDictionary(parent_name=type(self).__name__)
@@ -157,7 +169,7 @@ class Driver(object):
         self.supports.declare('linear_constraints', types=bool, default=False)
         self.supports.declare('two_sided_constraints', types=bool, default=False)
         self.supports.declare('multiple_objectives', types=bool, default=False)
-        self.supports.declare('integer_design_vars', types=bool, default=False)
+        self.supports.declare('integer_design_vars', types=bool, default=True)
         self.supports.declare('gradients', types=bool, default=False)
         self.supports.declare('active_set', types=bool, default=False)
         self.supports.declare('simultaneous_derivatives', types=bool, default=False)
@@ -166,10 +178,7 @@ class Driver(object):
         self.iter_count = 0
         self.cite = ""
 
-        self._coloring_info = coloring_mod._DEF_COMP_SPARSITY_ARGS.copy()
-        self._coloring_info['coloring'] = None
-        self._coloring_info['dynamic'] = False
-        self._coloring_info['static'] = None
+        self._coloring_info = coloring_mod._get_coloring_meta()
 
         self._total_jac_sparsity = None
         self._res_jacs = {}
@@ -252,8 +261,8 @@ class Driver(object):
         self._total_jac = None
 
         self._has_scaling = (
-            np.any([r['scaler'] is not None for r in itervalues(self._responses)]) or
-            np.any([dv['scaler'] is not None for dv in itervalues(self._designvars)])
+            np.any([r['total_scaler'] is not None for r in self._responses.values()]) or
+            np.any([dv['total_scaler'] is not None for dv in self._designvars.values()])
         )
 
         # Determine if any design variables are discrete.
@@ -268,9 +277,10 @@ class Driver(object):
         obj_set = set()
         dv_set = set()
 
-        self._remote_dvs = dv_dict = {}
-        self._remote_cons = con_dict = {}
-        self._remote_objs = obj_dict = {}
+        self._remote_dvs = remote_dv_dict = {}
+        self._remote_cons = remote_con_dict = {}
+        self._distributed_resp = dist_resp_dict = {}
+        self._remote_objs = remote_obj_dict = {}
 
         # Now determine if later we'll need to allgather cons, objs, or desvars.
         if model.comm.size > 1 and model._subsystems_allprocs:
@@ -278,6 +288,7 @@ class Driver(object):
             remote_dvs = set(self._designvars) - local_out_vars
             remote_cons = set(self._cons) - local_out_vars
             remote_objs = set(self._objs) - local_out_vars
+
             all_remote_vois = model.comm.allgather(
                 (remote_dvs, remote_cons, remote_objs))
             for rem_dvs, rem_cons, rem_objs in all_remote_vois:
@@ -291,17 +302,51 @@ class Driver(object):
             sizes = model._var_sizes['nonlinear']['output']
             abs2meta = model._var_allprocs_abs2meta
             for i, vname in enumerate(model._var_allprocs_abs_names['output']):
-                if abs2meta[vname]['distributed']:
+                distributed = abs2meta[vname]['distributed']
+                if distributed:
                     owner = sz = None
                 else:
                     owner = owning_ranks[vname]
                     sz = sizes[owner, i]
+
                 if vname in dv_set:
-                    dv_dict[vname] = (owner, sz)
+                    remote_dv_dict[vname] = (owner, sz)
+
+                # Note that design vars are not distributed.
+                elif distributed and vname in self._responses:
+                    idx = model._var_allprocs_abs2idx['nonlinear'][vname]
+                    dist_sizes = model._var_sizes['nonlinear']['output'][:, idx]
+
+                    # Determine which indices are on our proc.
+                    rank = model.comm.rank
+                    size = dist_sizes.size
+                    offsets = np.cumsum(dist_sizes)
+
+                    resp_dict = self._responses[vname]
+                    indices = resp_dict['indices']
+
+                    if indices is not None:
+                        local_indices = []
+                        true_sizes = np.zeros(size, dtype=INT_DTYPE)
+                        for index in indices:
+                            if index < 0:
+                                # Support for negative indices. Convert to positive index.
+                                index = index + np.sum(dist_sizes)
+                            irank = np.argwhere(offsets > index)[0][0]
+                            true_sizes[irank] += 1
+                            if rank == irank:
+                                new_index = index - offsets[irank] + dist_sizes[irank]
+                                local_indices.append(new_index)
+
+                        indices = local_indices
+                        dist_sizes = true_sizes
+
+                    dist_resp_dict[vname] = (indices, dist_sizes)
+
                 if vname in con_set:
-                    con_dict[vname] = (owner, sz)
+                    remote_con_dict[vname] = (owner, sz)
                 if vname in obj_set:
-                    obj_dict[vname] = (owner, sz)
+                    remote_obj_dict[vname] = (owner, sz)
 
         self._remote_responses = self._remote_cons.copy()
         self._remote_responses.update(self._remote_objs)
@@ -344,7 +389,6 @@ class Driver(object):
         """
         problem = self._problem()
         model = problem.model
-        rrank = problem.comm.rank
 
         incl = recording_options['includes']
         excl = recording_options['excludes']
@@ -352,45 +396,51 @@ class Driver(object):
         # includes and excludes for outputs are specified using promoted names
         abs2prom = model._var_allprocs_abs2prom['output']
 
-        allvars = []
-        # if desvars, etc. are not wanted, we need to exclude them from the outputs even if
-        # they match the includes list.
-        skip = set()
+        # 1. If record_outputs is True, get the set of outputs
+        # 2. Filter those using includes and excludes to get the baseline set of variables to record
+        # 3. Add or remove from that set any desvars, objs, and cons based on the recording
+        #    options of those
 
+        # includes and excludes for outputs are specified using _promoted_ names
+        # vectors are keyed on absolute name, discretes on relative/promoted name
+        myinputs = myoutputs = myresiduals = []
+
+        if recording_options['record_outputs']:
+            myoutputs = sorted([n for n, prom in abs2prom.items() if check_path(prom, incl, excl)])
+
+            views = model._outputs._views
+
+            if model._var_discrete['output']:
+                # if we have discrete outputs then residual name set doesn't match output one
+                if recording_options['record_residuals']:
+                    myresiduals = [n for n in myoutputs if n in views]
+            elif recording_options['record_residuals']:
+                myresiduals = myoutputs
+
+        elif recording_options['record_residuals']:
+            myresiduals = [n for n in model._residuals._views
+                           if check_path(abs2prom[n], incl, excl)]
+
+        myoutputs = set(myoutputs)
         if recording_options['record_desvars']:
-            allvars.extend(self._designvars)
-        else:
-            skip.update(self._designvars)
+            myoutputs.update(self._designvars)
         if recording_options['record_objectives'] or recording_options['record_responses']:
-            allvars.extend(self._objs)
-        else:
-            skip.update(self._objs)
+            myoutputs.update(self._objs)
         if recording_options['record_constraints'] or recording_options['record_responses']:
-            allvars.extend(self._cons)
-        else:
-            skip.update(self._cons)
-
-        vars2record = {
-            'output': [n for n in allvars
-                       if n in abs2prom and check_path(abs2prom[n], incl, excl, True)]
-        }
+            myoutputs.update(self._cons)
 
         # inputs (if in options). inputs use _absolute_ names for includes/excludes
         if 'record_inputs' in recording_options:
             if recording_options['record_inputs']:
                 # sort the results since _var_allprocs_abs2prom isn't ordered
-                vars2record['input'] = sorted([n for n in model._var_allprocs_abs2prom['input']
-                                               if check_path(n, incl, excl)])
-            else:
-                vars2record['input'] = []
+                myinputs = sorted([n for n in model._var_allprocs_abs2prom['input']
+                                  if check_path(n, incl, excl)])
 
-        if incl:
-            # loop over abs2prom (which includes both continuous and discrete outputs) since
-            # the order doesn't matter (we're sorting it at the end).
-            vars2record['output'].extend(n for n, prom in abs2prom.items() if n not in skip and
-                                         check_path(prom, incl, excl))
-            # remove dups and make sure order is the same on all procs
-            vars2record['output'] = sorted(set(vars2record['output']))
+        vars2record = {
+            'input': myinputs,
+            'output': list(myoutputs),
+            'residual': myresiduals
+        }
 
         return vars2record
 
@@ -403,9 +453,8 @@ class Driver(object):
         self._rec_mgr.startup(self)
 
         # record the system metadata to the recorders attached to this Driver
-        if self.recording_options['record_model_metadata']:
-            for sub in self._problem().model.system_iter(recurse=True, include_self=True):
-                self._rec_mgr.record_metadata(sub)
+        for sub in self._problem().model.system_iter(recurse=True, include_self=True):
+            self._rec_mgr.record_metadata(sub)
 
     def _get_voi_val(self, name, meta, remote_vois, driver_scaling=True, rank=None):
         """
@@ -437,11 +486,18 @@ class Driver(object):
         model = self._problem().model
         comm = model.comm
         vec = model._outputs._views_flat
+        distributed_vars = self._distributed_resp
         indices = meta['indices']
 
+        if MPI:
+            distributed = comm.size > 0 and name in distributed_vars
+        else:
+            distributed = False
+
         if name in remote_vois:
             owner, size = remote_vois[name]
             # if var is distributed or only gathering to one rank
+            # TODO - support distributed var under a parallel group.
             if owner is None or rank is not None:
                 val = model._get_val(name, get_remote=True, rank=rank, flat=True)
                 if indices is not None:
@@ -458,6 +514,17 @@ class Driver(object):
                     val = np.empty(size)
 
                 comm.Bcast(val, root=owner)
+
+        elif distributed:
+            local_val = model._get_val(name, flat=True)
+            local_indices, sizes = distributed_vars[name]
+            if local_indices is not None:
+                local_val = local_val[local_indices]
+            offsets = np.zeros(sizes.size, dtype=INT_DTYPE)
+            offsets[1:] = np.cumsum(sizes[:-1])
+            val = np.zeros(np.sum(sizes))
+            comm.Allgatherv(local_val, [val, sizes, offsets, MPI.DOUBLE])
+
         else:
             if name in self._designvars_discrete:
                 val = model._discrete_outputs[name]
@@ -480,11 +547,11 @@ class Driver(object):
 
         if self._has_scaling and driver_scaling:
             # Scale design variable values
-            adder = meta['adder']
+            adder = meta['total_adder']
             if adder is not None:
                 val += adder
 
-            scaler = meta['scaler']
+            scaler = meta['total_scaler']
             if scaler is not None:
                 val *= scaler
 
@@ -499,7 +566,8 @@ class Driver(object):
         dict
            Dictionary containing values of each design variable.
         """
-        return {n: self._get_voi_val(n, dv, self._remote_dvs) for n, dv in self._designvars.items()}
+        return {n: self._get_voi_val(n, dv, self._remote_dvs)
+                for n, dv in self._designvars.items()}
 
     def set_design_var(self, name, value):
         """
@@ -525,7 +593,20 @@ class Driver(object):
             indices = slice(None)
 
         if name in self._designvars_discrete:
-            problem.model._discrete_outputs[name] = int(value)
+
+            # Note, drivers set values here and generally should know it is setting an integer.
+            # However, the DOEdriver may pull a non-integer value from its generator, so we
+            # convert it.
+            if isinstance(value, float):
+                value = int(value)
+            elif isinstance(value, np.ndarray):
+                if isinstance(problem.model._discrete_outputs[name], int):
+                    # Setting an integer value with a 1D array - don't want to convert to array.
+                    value = int(value)
+                else:
+                    value = value.astype(np.int)
+
+            problem.model._discrete_outputs[name] = value
 
         else:
             desvar = problem.model._outputs._views_flat[name]
@@ -533,11 +614,11 @@ class Driver(object):
 
             # Undo driver scaling when setting design var values into model.
             if self._has_scaling:
-                scaler = meta['scaler']
+                scaler = meta['total_scaler']
                 if scaler is not None:
                     desvar[indices] *= 1.0 / scaler
 
-                adder = meta['adder']
+                adder = meta['total_adder']
                 if adder is not None:
                     desvar[indices] -= adder
 
@@ -557,7 +638,8 @@ class Driver(object):
         dict
            Dictionary containing values of each objective.
         """
-        return {n: self._get_voi_val(n, obj, self._remote_objs, driver_scaling=driver_scaling)
+        return {n: self._get_voi_val(n, obj, self._remote_objs,
+                                     driver_scaling=driver_scaling)
                 for n, obj in self._objs.items()}
 
     def get_constraint_values(self, ctype='all', lintype='all', driver_scaling=True):
@@ -614,7 +696,7 @@ class Driver(object):
             The nonlinear response names in order.
         """
         order = list(self._objs)
-        order.extend(n for n, meta in iteritems(self._cons)
+        order.extend(n for n, meta in self._cons.items()
                      if not ('linear' in meta and meta['linear']))
         return order
 
@@ -637,8 +719,10 @@ class Driver(object):
         self._objs = objs = OrderedDict()
         self._cons = cons = OrderedDict()
 
+        model._setup_driver_units()
+
         self._responses = resps = model.get_responses(recurse=True)
-        for name, data in iteritems(resps):
+        for name, data in resps.items():
             if data['type'] == 'con':
                 cons[name] = data
             else:
@@ -648,7 +732,7 @@ class Driver(object):
 
         # Gather up the information for design vars.
         self._designvars = designvars = model.get_design_vars(recurse=True)
-        desvar_size = sum(data['size'] for data in itervalues(designvars))
+        desvar_size = sum(data['size'] for data in designvars.values())
 
         return response_size, desvar_size
 
@@ -670,7 +754,8 @@ class Driver(object):
         self.iter_count += 1
         return False
 
-    def _compute_totals(self, of=None, wrt=None, return_format='flat_dict', global_names=True):
+    def _compute_totals(self, of=None, wrt=None, return_format='flat_dict', global_names=None,
+                        use_abs_names=True):
         """
         Compute derivatives of desired quantities with respect to desired inputs.
 
@@ -689,7 +774,9 @@ class Driver(object):
             returns them in a dictionary whose keys are tuples of form (of, wrt). For
             the scipy optimizer, 'array' is also supported.
         global_names : bool
-            Set to True when passing in global names to skip some translation steps.
+            Deprecated.  Use 'use_abs_names' instead.
+        use_abs_names : bool
+            Set to True when passing in absolute names to skip some translation steps.
 
         Returns
         -------
@@ -699,19 +786,24 @@ class Driver(object):
         problem = self._problem()
         total_jac = self._total_jac
         debug_print = 'totals' in self.options['debug_print'] and (not MPI or
-                                                                   MPI.COMM_WORLD.rank == 0)
+                                                                   problem.comm.rank == 0)
 
         if debug_print:
             header = 'Driver total derivatives for iteration: ' + str(self.iter_count)
             print(header)
             print(len(header) * '-' + '\n')
 
+        if global_names is not None:
+            warn_deprecation("'global_names' is deprecated in calls to _compute_totals. "
+                             "Use 'use_abs_names' instead.")
+            use_abs_names = global_names
+
         if problem.model._owns_approx_jac:
             self._recording_iter.push(('_compute_totals_approx', 0))
 
             try:
                 if total_jac is None:
-                    total_jac = _TotalJacInfo(problem, of, wrt, global_names,
+                    total_jac = _TotalJacInfo(problem, of, wrt, use_abs_names,
                                               return_format, approx=True, debug_print=debug_print)
 
                     # Don't cache linear constraint jacobian
@@ -726,7 +818,7 @@ class Driver(object):
 
         else:
             if total_jac is None:
-                total_jac = _TotalJacInfo(problem, of, wrt, global_names, return_format,
+                total_jac = _TotalJacInfo(problem, of, wrt, use_abs_names, return_format,
                                           debug_print=debug_print)
 
                 # don't cache linear constraint jacobian
@@ -845,27 +937,16 @@ class Driver(object):
             raise RuntimeError("Driver '%s' does not support simultaneous derivatives." %
                                self._get_name())
 
-    def set_simul_deriv_color(self, coloring):
-        """
-        See use_fixed_coloring. This method is deprecated.
-
-        Parameters
-        ----------
-        coloring : str or Coloring
-            Information about simultaneous coloring for design vars and responses.  If a
-            string, then coloring is assumed to be the name of a file that contains the
-            coloring information in pickle format. Otherwise it must be a Coloring object.
-            See the docstring for Coloring for details.
-
-        """
-        warn_deprecation("set_simul_deriv_color is deprecated.  Use use_fixed_coloring instead.")
-        self.use_fixed_coloring(coloring)
-
-    def _setup_tot_jac_sparsity(self):
+    def _setup_tot_jac_sparsity(self, coloring=None):
         """
         Set up total jacobian subjac sparsity.
 
         Drivers that can use subjac sparsity should override this.
+
+        Parameters
+        ----------
+        coloring : Coloring or None
+            Current coloring.
         """
         pass
 
@@ -892,7 +973,7 @@ class Driver(object):
         if coloring is not None:
             return coloring
 
-        if static is coloring_mod._STD_COLORING_FNAME or isinstance(static, string_types):
+        if static is coloring_mod._STD_COLORING_FNAME or isinstance(static, str):
             if static is coloring_mod._STD_COLORING_FNAME:
                 fname = self._get_total_coloring_fname()
             else:
@@ -938,10 +1019,11 @@ class Driver(object):
         Optionally print some debugging information before the model runs.
         """
         debug_opt = self.options['debug_print']
+        rank = self._problem().comm.rank
         if not debug_opt or debug_opt == ['totals']:
             return
 
-        if not MPI or MPI.COMM_WORLD.rank == 0:
+        if not MPI or rank == 0:
             header = 'Driver debug print for iter coord: {}'.format(
                 self._recording_iter.get_formatted_iteration_coordinate())
             print(header)
@@ -950,7 +1032,7 @@ class Driver(object):
         if 'desvars' in debug_opt:
             model = self._problem().model
             desvar_vals = {n: model._get_val(n, get_remote=True, rank=0) for n in self._designvars}
-            if not MPI or MPI.COMM_WORLD.rank == 0:
+            if not MPI or rank == 0:
                 print("Design Vars")
                 if desvar_vals:
                     pprint.pprint(desvar_vals)
@@ -964,9 +1046,11 @@ class Driver(object):
         """
         Optionally print some debugging information after the model runs.
         """
+        rank = self._problem().comm.rank
+
         if 'nl_cons' in self.options['debug_print']:
             cons = self.get_constraint_values(lintype='nonlinear', driver_scaling=False)
-            if not MPI or MPI.COMM_WORLD.rank == 0:
+            if not MPI or rank == 0:
                 print("Nonlinear constraints")
                 if cons:
                     pprint.pprint(cons)
@@ -976,7 +1060,7 @@ class Driver(object):
 
         if 'ln_cons' in self.options['debug_print']:
             cons = self.get_constraint_values(lintype='linear', driver_scaling=False)
-            if not MPI or MPI.COMM_WORLD.rank == 0:
+            if not MPI or rank == 0:
                 print("Linear constraints")
                 if cons:
                     pprint.pprint(cons)
@@ -986,7 +1070,7 @@ class Driver(object):
 
         if 'objs' in self.options['debug_print']:
             objs = self.get_objective_values(driver_scaling=False)
-            if not MPI or MPI.COMM_WORLD.rank == 0:
+            if not MPI or rank == 0:
                 print("Objectives")
                 if objs:
                     pprint.pprint(objs)
@@ -1051,15 +1135,41 @@ def record_iteration(requester, prob, case_name):
     filt = requester._filtered_vars_to_record
     model = prob.model
 
+    inputs, outputs, residuals = model.get_nonlinear_vectors()
+
     parallel = requester._rec_mgr._check_parallel() if model.comm.size > 1 else False
 
-    outs = model._retrieve_data_of_kind(filt, 'output', 'nonlinear', parallel)
-    ins = model._retrieve_data_of_kind(filt, 'input', 'nonlinear', parallel)
+    discrete_inputs = model._discrete_inputs
+    discrete_outputs = model._discrete_outputs
 
-    data = {
-        'output': outs,
-        'input': ins
-    }
+    data = {'input': {}, 'output': {}, 'residual': {}}
+    if requester.recording_options['record_inputs'] and (inputs._names or len(discrete_inputs) > 0):
+        data['input'] = model._retrieve_data_of_kind(filt, 'input', 'nonlinear', parallel)
+
+    if requester.recording_options['record_outputs'] and \
+            (outputs._names or len(discrete_outputs) > 0):
+        data['output'] = model._retrieve_data_of_kind(filt, 'output', 'nonlinear', parallel)
+
+    if requester.recording_options['record_residuals'] and residuals._names:
+        data['residual'] = model._retrieve_data_of_kind(filt, 'residual', 'nonlinear', parallel)
+
+    from openmdao.core.problem import Problem
+    if isinstance(requester, Problem):
+        if requester.recording_options['record_derivatives'] and \
+                prob.driver._designvars and prob.driver._responses:
+            totals = requester.compute_totals(return_format='flat_dict_structured_key')
+            data['totals'] = totals
+
+        # Record solver info
+        if requester.recording_options['record_abs_error'] or \
+                requester.recording_options['record_rel_error']:
+            norm = model._residuals.get_norm()
+        if requester.recording_options['record_abs_error']:
+            data['abs'] = norm
+        if requester.recording_options['record_rel_error']:
+            solver = model.nonlinear_solver
+            norm0 = solver._norm0 if solver._norm0 != 0.0 else 1.0  # runonce never sets _norm0
+            data['rel'] = norm / norm0
 
     requester._rec_mgr.record_iteration(requester, data,
                                         requester._get_recorder_metadata(case_name))
