@@ -1,10 +1,6 @@
 """Define the ExplicitComponent class."""
 
-from __future__ import division
-
 import numpy as np
-from six import itervalues, iteritems
-from six.moves import range
 
 from openmdao.core.component import Component, _full_slice
 from openmdao.utils.class_util import overrides_method
@@ -220,7 +216,7 @@ class ExplicitComponent(Component):
                                                          tags=tags)
 
     def _approx_subjac_keys_iter(self):
-        for abs_key, meta in iteritems(self._subjacs_info):
+        for abs_key, meta in self._subjacs_info.items():
             if 'method' in meta:
                 method = meta['method']
                 if (method is not None and method in self._approx_schemes and abs_key[1]
@@ -405,7 +401,7 @@ class ExplicitComponent(Component):
         with self._unscaled_context(outputs=[self._outputs], residuals=[self._residuals]):
             # Computing the approximation before the call to compute_partials allows users to
             # override FD'd values.
-            for approximation in itervalues(self._approx_schemes):
+            for approximation in self._approx_schemes.values():
                 approximation.compute_approximations(self, jac=self._jacobian)
 
             if self._has_compute_partials:
