@@ -1,11 +1,5 @@
 """Define the IndepVarComp class."""
 
-# note: this is a Python 3.3 change, clean this up for OpenMDAO 3.x
-try:
-    from collections.abc import Iterable
-except ImportError:
-    from collections import Iterable
-
 from openmdao.core.explicitcomponent import ExplicitComponent
 from openmdao.utils.general_utils import make_set
 
@@ -13,18 +7,6 @@ from openmdao.utils.general_utils import make_set
 class IndepVarComp(ExplicitComponent):
     """
     Class to use when all output variables are independent.
-
-    Attributes
-    ----------
-    _indep : tuple
-        List of tuples of the form [(str, value, kwargs), ...].
-        The value can be float or ndarray, and kwargs is a dictionary
-    _indep_external : list
-        list of this component's independent variables that are declared externally
-        via the add_output method.
-    _indep_external_discrete : list
-        list of this component's discrete independent variables that are declared externally
-        via the add_discrete_output method.
     """
 
     def __init__(self, name=None, val=1.0, **kwargs):
@@ -42,9 +24,6 @@ class IndepVarComp(ExplicitComponent):
             keyword arguments.
         """
         super(IndepVarComp, self).__init__()
-        self._indep = []
-        self._indep_external = []
-        self._indep_external_discrete = []
 
         if 'tags' not in kwargs:
             kwargs['tags'] = {'indep_var'}
@@ -53,7 +32,7 @@ class IndepVarComp(ExplicitComponent):
 
         # A single variable is declared during instantiation
         if isinstance(name, str):
-            self._indep.append((name, val, kwargs))
+            super(IndepVarComp, self).add_output(name, val, **kwargs)
 
         elif name is None:
             pass
@@ -69,31 +48,17 @@ class IndepVarComp(ExplicitComponent):
                 raise ValueError("IndepVarComp init: '%s' is not supported "
                                  "in IndepVarComp." % illegal)
 
-    def _post_configure(self):
+    def _configure_check(self):
         """
-        Do any remaining setup that had to wait until after final user configuration.
+        Do any error checking on i/o configuration.
         """
-        # set static mode to False because we are doing things that would normally be done in setup
-        self._static_mode = False
-
-        self._var_rel_names = {'input': [], 'output': []}
-        self._var_rel2meta = {}
-
-        for (name, val, kwargs) in self._indep + self._indep_external:
-            super(IndepVarComp, self).add_output(name, val, **kwargs)
-
-        for (name, val, kwargs) in self._indep_external_discrete:
-            super(IndepVarComp, self).add_discrete_output(name, val, **kwargs)
-
-        if len(self._indep) + len(self._indep_external) + len(self._indep_external_discrete) == 0:
+        if len(self._static_var_rel2meta) + len(self._var_rel2meta) == 0:
             raise RuntimeError("{}: No outputs (independent variables) have been declared. "
                                "They must either be declared during "
                                "instantiation or by calling add_output or add_discrete_output "
                                "afterwards.".format(self.msginfo))
 
-        self._static_mode = True
-
-        super(IndepVarComp, self)._post_configure()
+        super(IndepVarComp, self)._configure_check()
 
     def add_output(self, name, val=1.0, shape=None, units=None, res_units=None, desc='',
                    lower=None, upper=None, ref=1.0, ref0=0.0, res_ref=None, tags=None):
@@ -153,7 +118,7 @@ class IndepVarComp(ExplicitComponent):
                   'lower': lower, 'upper': upper, 'ref': ref, 'ref0': ref0,
                   'res_ref': res_ref, 'tags': tags
                   }
-        self._indep_external.append((name, val, kwargs))
+        super(IndepVarComp, self).add_output(name, val, **kwargs)
 
     def add_discrete_output(self, name, val, desc='', tags=None):
         """
@@ -177,7 +142,7 @@ class IndepVarComp(ExplicitComponent):
             tags = make_set(tags, name='tags') | {'indep_var'}
 
         kwargs = {'desc': desc, 'tags': tags}
-        self._indep_external_discrete.append((name, val, kwargs))
+        super(IndepVarComp, self).add_discrete_output(name, val, **kwargs)
 
     def _linearize(self, jac=None, sub_do_ln=False):
         """
