@@ -32,7 +32,7 @@ from openmdao.utils.general_utils import ContainsAll, pad_name, simple_warning,
 from openmdao.utils.mpi import FakeComm
 from openmdao.utils.mpi import MPI
 from openmdao.utils.name_maps import prom_name2abs_name
-from openmdao.utils.options_dictionary import OptionsDictionary
+from openmdao.utils.options_dictionary import OptionsDictionary, _undefined
 from openmdao.utils.units import unit_conversion
 from openmdao.utils import coloring as coloring_mod
 from openmdao.utils.name_maps import abs_key2rel_key
@@ -57,7 +57,6 @@ ErrorTuple = namedtuple('ErrorTuple', ['forward', 'reverse', 'forward_reverse'])
 MagnitudeTuple = namedtuple('MagnitudeTuple', ['forward', 'reverse', 'fd'])
 
 _contains_all = ContainsAll()
-_undefined = object()
 
 
 CITATION = """@article{openmdao_2019,
@@ -217,6 +216,12 @@ class Problem(object):
         self.recording_options.declare('record_derivatives', types=bool, default=False,
                                        desc='Set to True to record derivatives for the problem '
                                             'level')
+        self.recording_options.declare('record_abs_error', types=bool, default=True,
+                                       desc='Set to True to record absolute error of '
+                                            'model nonlinear solver')
+        self.recording_options.declare('record_rel_error', types=bool, default=True,
+                                       desc='Set to True to record relative error of model \
+                                       nonlinear solver')
         self.recording_options.declare('includes', types=list, default=['*'],
                                        desc='Patterns for variables to include in recording. \
                                        Uses fnmatch wildcards')
@@ -391,7 +396,7 @@ class Problem(object):
 
         val = self.model._get_val(name, units=units, indices=indices, get_remote=get_remote)
 
-        if val is System._undefined:
+        if val is _undefined:
             if get_remote:
                 raise KeyError('{}: Variable name "{}" not found.'.format(self.msginfo, name))
             else:
@@ -1339,6 +1344,8 @@ class Problem(object):
             'step_calc': step_calc,
         }
         approx = model._owns_approx_jac
+        approx_of = model._owns_approx_of
+        approx_wrt = model._owns_approx_wrt
         old_jac = model._jacobian
         old_subjacs = model._subjacs_info.copy()
 
@@ -1352,15 +1359,25 @@ class Problem(object):
         if not approx:
             model._jacobian = old_jac
             model._owns_approx_jac = False
+            model._owns_approx_of = approx_of
+            model._owns_approx_wrt = approx_wrt
             model._subjacs_info = old_subjacs
 
         # Assemble and Return all metrics.
         data = {}
         data[''] = {}
+        resp = self.driver._responses
+        # TODO key should not be fwd when exact computed in rev mode or auto
         for key, val in Jcalc.items():
             data[''][key] = {}
             data[''][key]['J_fwd'] = val
             data[''][key]['J_fd'] = Jfd[key]
+
+            # Display whether indices were declared when response was added.
+            of = key[0]
+            if of in resp and resp[of]['indices'] is not None:
+                data[''][key]['indices'] = len(resp[of]['indices'])
+
         fd_args['method'] = method
 
         if out_stream == _DEFAULT_OUT_STREAM:
@@ -1811,6 +1828,7 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
             do_rev_dp = not totals and matrix_free and directional
 
             derivative_info = derivatives[of, wrt]
+            # TODO total derivs may have been computed in rev mode, not fwd
             forward = derivative_info['J_fwd']
             fd = derivative_info['J_fd']
             if do_rev:
@@ -1870,6 +1888,11 @@ def _assemble_derivative_data(derivative_data, rel_error_tol, abs_error_tol, out
                     del derivative_data[sys_name][rel_key]
                     continue
 
+            # Informative output for responses that were declared with an index.
+            indices = derivative_info.get('indices')
+            if indices is not None:
+                of = '{} (index size: {})'.format(of, indices)
+
             if not suppress_output:
 
                 if compact_print:
