@@ -1648,112 +1648,6 @@ class TestProblem(unittest.TestCase):
             ('sub.mcomp.b2', {'value': [6.]}),
         ])
 
-    def test_feature_configure_add_input_output(self):
-        """
-        A simple example to compute the resultant force on an aircraft using data
-        from an external source. Demonstrates adding I/O in the 'configure' method.
-        """
-        import numpy as np
-        import openmdao.api as om
-
-        class FlightDataComp(om.ExplicitComponent):
-            """
-            Simulate data generated by an external source/code
-            """
-            def setup(self):
-                # number of points may not be known a priori
-                n = 3
-
-                # The vector represents forces at n time points (rows) in 2 dimensional plane (cols)
-                self.add_output(name='thrust', shape=(n, 2), units='kN')
-                self.add_output(name='drag', shape=(n, 2), units='kN')
-                self.add_output(name='lift', shape=(n, 2), units='kN')
-                self.add_output(name='weight', shape=(n, 2), units='kN')
-
-            def compute(self, inputs, outputs):
-                outputs['thrust'][:, 0] = [500, 600, 700]
-                outputs['drag'][:, 0]  = [400, 400, 400]
-                outputs['weight'][:, 1] = [1000, 1001, 1002]
-                outputs['lift'][:, 1]  = [1000, 1000, 1000]
-
-
-        class ForceModel(om.Group):
-            def setup(self):
-                self.add_subsystem('flightdatacomp', FlightDataComp(),
-                                   promotes_outputs=['thrust', 'drag', 'lift', 'weight'])
-
-                self.add_subsystem('totalforcecomp', om.AddSubtractComp())
-
-            def configure(self):
-                # Some models that require self-interrogation need to be able to add
-                # I/O in components from the configure method of their containing groups.
-                # In this case, we can only determine the 'vec_size' for totalforcecomp
-                # after flightdatacomp has been setup.
-
-                flight_data = dict(self.flightdatacomp.list_outputs(shape=True, out_stream=None))
-                data_shape = flight_data['thrust']['shape']
-
-                self.totalforcecomp.add_equation('total_force',
-                                                 input_names=['thrust', 'drag', 'lift', 'weight'],
-                                                 vec_size=data_shape[0], length=data_shape[1],
-                                                 scaling_factors=[1, -1, 1, -1], units='kN')
-
-                p.model.connect('thrust', 'totalforcecomp.thrust')
-                p.model.connect('drag', 'totalforcecomp.drag')
-                p.model.connect('lift', 'totalforcecomp.lift')
-                p.model.connect('weight', 'totalforcecomp.weight')
-
-
-        p = om.Problem(model=ForceModel())
-        p.setup()
-        p.run_model()
-
-        assert_near_equal(p.get_val('totalforcecomp.total_force', units='kN'),
-                         np.array([[100, 200, 300], [0, -1, -2]]).T)
-
-    def test_feature_system_configure(self):
-        import openmdao.api as om
-
-        class ImplSimple(om.ImplicitComponent):
-
-            def setup(self):
-                self.add_input('a', val=1.)
-                self.add_output('x', val=0.)
-
-            def apply_nonlinear(self, inputs, outputs, residuals):
-                residuals['x'] = np.exp(outputs['x']) - \
-                    inputs['a']**2 * outputs['x']**2
-
-            def linearize(self, inputs, outputs, jacobian):
-                jacobian['x', 'x'] = np.exp(outputs['x']) - \
-                    2 * inputs['a']**2 * outputs['x']
-                jacobian['x', 'a'] = -2 * inputs['a'] * outputs['x']**2
-
-        class Sub(om.Group):
-            def setup(self):
-                self.add_subsystem('comp', ImplSimple())
-
-            def configure(self):
-                # This solver won't solve the system. We want
-                # to override it in the parent.
-                self.nonlinear_solver = om.NonlinearBlockGS()
-
-        class Super(om.Group):
-            def setup(self):
-                self.add_subsystem('sub', Sub())
-
-            def configure(self):
-                # This will solve it.
-                self.sub.nonlinear_solver = om.NewtonSolver(solve_subsystems=False)
-                self.sub.linear_solver = om.ScipyKrylov()
-
-        top = om.Problem(model=Super())
-
-        top.setup()
-
-        print(isinstance(top.model.sub.nonlinear_solver, om.NewtonSolver))
-        print(isinstance(top.model.sub.linear_solver, om.ScipyKrylov))
-
     def test_feature_post_setup_solver_configure(self):
         import openmdao.api as om
 
@@ -2000,5 +1894,27 @@ class NestedProblemTestCase(unittest.TestCase):
         p.run_model()
 
 
+class SystemInTwoProblemsTestCase(unittest.TestCase):
+    def test_2problems(self):
+        prob = om.Problem()
+        G1 = prob.model.add_subsystem("G1", om.Group())
+        G2 = G1.add_subsystem('G2', om.Group(), promotes_inputs=['x'])
+        G2.add_subsystem('C1', om.ExecComp('y = 2 * x'), promotes_inputs=['x'])
+        G2.add_subsystem('C2', om.ExecComp('y = 3 * x'), promotes_inputs=['x'])
+
+        prob.setup()
+        prob.run_model()
+
+        # 2nd problem
+        prob = om.Problem()
+        prob.model = G2
+
+        prob.setup()
+        prob.run_model()
+
+        np.testing.assert_allclose(prob['C1.y'], 2.0)
+        np.testing.assert_allclose(prob['C2.y'], 3.0)
+
+
 if __name__ == "__main__":
     unittest.main()
