@@ -3,26 +3,35 @@ Helper class for total jacobian computation.
 """
 from collections import OrderedDict, defaultdict
 from copy import deepcopy
+import os
 import pprint
 import sys
 import time
-import traceback
 
 import numpy as np
 
-try:
-    from petsc4py import PETSc
-    from openmdao.vectors.petsc_vector import PETScVector
-except ImportError:
-    PETSc = None
-
 from openmdao.vectors.vector import INT_DTYPE
 from openmdao.utils.general_utils import ContainsAll, simple_warning
-from openmdao.utils.record_util import create_local_meta
 from openmdao.utils.mpi import MPI
 from openmdao.utils.coloring import _initialize_model_approx, Coloring
-from openmdao.jacobians.dictionary_jacobian import DictionaryJacobian
 
+# Attempt to import petsc4py.
+# If OPENMDAO_REQUIRE_MPI is set to a recognized positive value, attempt import
+# and raise exception on failure. If set to anything else, no import is attempted.
+if 'OPENMDAO_REQUIRE_MPI' in os.environ:
+    if os.environ['OPENMDAO_REQUIRE_MPI'].lower() in ['always', '1', 'true', 'yes']:
+        from petsc4py import PETSc
+    else:
+        PETSc = None
+# If OPENMDAO_REQUIRE_MPI is unset, attempt to import petsc4py, but continue on failure
+# with a notification.
+else:
+    try:
+        from petsc4py import PETSc
+    except ImportError:
+        PETSc = None
+        sys.stdout.write("Unable to import petsc4py. Parallel processing unavailable.\n")
+        sys.stdout.flush()
 
 _contains_all = ContainsAll()
 
@@ -56,10 +65,10 @@ class _TotalJacInfo(object):
     model : <System>
         The top level System of the System tree.
     of_meta : dict
-        Map of absoute output 'of' var name to tuples of the form
+        Map of absolute output 'of' var name to tuples of the form
         (row/column slice, indices, distrib).
     wrt_meta : dict
-        Map of absoute output 'wrt' var name to tuples of the form
+        Map of absolute output 'wrt' var name to tuples of the form
         (row/column slice, indices, distrib).
     output_list : list of str
         List of names of output variables for this total jacobian.  In fwd mode, outputs
@@ -102,6 +111,9 @@ class _TotalJacInfo(object):
         driver_scaling : bool
             If True (default), scale derivative values by the quantities specified when the desvars
             and responses were added. If False, leave them unscaled.
+        _distributed_resp : dict
+            Dict of constraints that are distributed outputs. Key is rank, values are
+            (local indices, local sizes).
         """
         driver = problem.driver
         prom2abs = problem.model._var_allprocs_prom2abs_list['output']
@@ -180,6 +192,7 @@ class _TotalJacInfo(object):
         self.output_meta = {'fwd': responses, 'rev': design_vars}
         self.input_vec = {'fwd': model._vectors['residual'], 'rev': model._vectors['output']}
         self.output_vec = {'fwd': model._vectors['output'], 'rev': model._vectors['residual']}
+        self._distributed_resp = driver._distributed_resp
 
         abs2meta = model._var_allprocs_abs2meta
 
@@ -238,6 +251,7 @@ class _TotalJacInfo(object):
 
         # create scratch array for jac scatters
         self.jac_scratch = None
+
         if self.comm.size > 1:
             # need 2 scratch vectors of the same size here
             scratch = np.zeros(max(J.shape), dtype=J.dtype)
@@ -251,6 +265,7 @@ class _TotalJacInfo(object):
         if not approx:
             self.sol2jac_map = {}
             for mode in modes:
+
                 self.sol2jac_map[mode] = self._get_sol2jac_map(self.output_list[mode],
                                                                self.output_meta[mode],
                                                                abs2meta, mode)
@@ -286,9 +301,10 @@ class _TotalJacInfo(object):
     def _compute_jac_scatters(self, mode, rowcol_size):
         self.jac_scatters[mode] = jac_scatters = {}
         model = self.model
+        nproc = self.comm.size
 
-        if mode == 'fwd' and self.comm.size > 1 or (model._full_comm is not None and
-                                                    model._full_comm.size > 1):
+        if mode == 'fwd' and nproc > 1 or (model._full_comm is not None and
+                                           model._full_comm.size > 1):
             tgt_vec = PETSc.Vec().createWithArray(np.zeros(rowcol_size, dtype=float),
                                                   comm=self.comm)
             self.tgt_petsc[mode] = tgt_vec
@@ -314,8 +330,7 @@ class _TotalJacInfo(object):
                     if abs2meta[name]['distributed']:
                         srcinds = name2jinds[name]
                         myinds = srcinds + myoffset
-                        var_idx = abs2idx[name]
-                        for rank in range(self.comm.size):
+                        for rank in range(nproc):
                             if rank != myrank:
                                 offset = rowcol_size * rank   # J is same size on all procs
                                 full_j_srcs.append(myinds)
@@ -324,7 +339,7 @@ class _TotalJacInfo(object):
                         srcinds = name2jinds[name]
                         myinds = srcinds + myoffset
                         var_idx = abs2idx[name]
-                        for rank in range(self.comm.size):
+                        for rank in range(nproc):
                             if rank != myrank and sizes[rank, var_idx] == 0:
                                 offset = rowcol_size * rank   # J is same size on all procs
                                 full_j_srcs.append(myinds)
@@ -450,7 +465,10 @@ class _TotalJacInfo(object):
                 # if name is in vois, then it has been declared as either a design var or
                 # a constraint or an objective.
                 meta = vois[name]
-                end += meta['size']
+                if meta['distributed'] is True:
+                    end += meta['global_size']
+                else:
+                    end += meta['size']
 
                 parallel_deriv_color = meta['parallel_deriv_color']
                 matmat = meta['vectorize_derivs']
@@ -460,7 +478,7 @@ class _TotalJacInfo(object):
                 if matmat or parallel_deriv_color:
                     rhsname = name
 
-                    if parallel_deriv_color and self.debug_print:
+                    if parallel_deriv_color:
                         if parallel_deriv_color not in self.par_deriv:
                             self.par_deriv[parallel_deriv_color] = []
                         self.par_deriv[parallel_deriv_color].append(name)
@@ -517,8 +535,7 @@ class _TotalJacInfo(object):
                         loc_i[loc] = irange[loc] - gstart
                 else:
                     loc_i[loc] = irange[loc]
-                    if not in_var_meta['distributed']:
-                        loc_i[loc] -= gstart
+                    loc_i[loc] -= gstart
 
                 loc_offset = offsets[iproc, in_var_idx] - offsets[iproc, 0]
                 loc_i[loc] += loc_offset
@@ -636,8 +653,6 @@ class _TotalJacInfo(object):
         jac_idxs = {}
         model = self.model
         fwd = mode == 'fwd'
-        missing = False
-        full_slice = slice(None)
         myproc = self.comm.rank
         name2jinds = {}  # map varname to jac row or col idxs that we must scatter to other procs
 
@@ -645,7 +660,6 @@ class _TotalJacInfo(object):
             inds = []
             jac_inds = []
             sizes = model._var_sizes[vecname]['output']
-            offsets = model._var_offsets[vecname]['output']
             ncols = model._vectors['output'][vecname]._ncol
             slices = model._vectors['output'][vecname].get_slice_dict()
             abs2idx = model._var_allprocs_abs2idx[vecname]
@@ -663,19 +677,21 @@ class _TotalJacInfo(object):
                 if name in abs2idx and name in slices:
                     var_idx = abs2idx[name]
                     slc = slices[name]
-                    if meta['distributed']:
-                        dist_offset = np.sum(sizes[:myproc, var_idx])
+                    if MPI and meta['distributed'] and model.comm.size > 1:
                         if indices is not None:
-                            dist_end = dist_offset + sizes[rank, var_idx]
-                            on_myproc = np.logical_and(dist_offset <= indices, indices < dist_end)
-                            if np.any(on_myproc):
-                                loc_inds = indices[on_myproc]
-                                inds.append(loc_inds - dist_offset)
-                                jac_inds.append(np.arange(jstart, loc_inds - jstart,
-                                                dtype=INT_DTYPE))
-                                if fwd:
-                                    name2jinds[name] = jac_inds[-1]
+                            if name in self._distributed_resp:
+                                local_idx, sizes_idx = self._distributed_resp[name]
+
+                            dist_offset = np.sum(sizes_idx[:myproc])
+                            full_inds = np.arange(slc.start / ncols, slc.stop / ncols,
+                                                  dtype=INT_DTYPE)
+                            inds.append(full_inds[local_idx])
+                            jac_inds.append(jstart + dist_offset +
+                                            np.arange(len(local_idx), dtype=INT_DTYPE))
+                            if fwd:
+                                name2jinds[name] = jac_inds[-1]
                         else:
+                            dist_offset = np.sum(sizes[:myproc, var_idx])
                             inds.append(np.arange(slc.start / ncols, slc.stop / ncols,
                                                   dtype=INT_DTYPE))
                             jac_inds.append(np.arange(jstart + dist_offset,
@@ -733,8 +749,12 @@ class _TotalJacInfo(object):
 
         for name in names:
             if name in vois:
+                voi = vois[name]
                 # this 'size' already takes indices into account
-                size = vois[name]['size']
+                if voi['distributed'] is True:
+                    size = voi['global_size']
+                else:
+                    size = voi['size']
                 indices = vois[name]['indices']
             else:
                 size = abs2meta[name]['global_size']
@@ -1336,7 +1356,13 @@ class _TotalJacInfo(object):
                             model._solve_linear(model._lin_vec_names, self.mode, rel_systems)
                             self._save_linear_solution(vec_names, cache_key, self.mode)
                         else:
-                            model._solve_linear(model._lin_vec_names, mode, rel_systems)
+                            if par_deriv and key in par_deriv:
+                                # parallel colored derivatives only need to solve
+                                # the vectors relevant to this color, not all of them
+                                vecnames_par_deriv = par_deriv[key].copy()
+                                model._solve_linear(vecnames_par_deriv, mode, rel_systems)
+                            else:
+                                model._solve_linear(model._lin_vec_names, mode, rel_systems)
 
                     if debug_print:
                         print('Elapsed Time:', time.time() - t0, '\n', flush=True)
@@ -1375,6 +1401,7 @@ class _TotalJacInfo(object):
         of = self.of
         wrt = self.wrt
         model = self.model
+        comm = model.comm
         return_format = self.return_format
 
         # Prepare model for calculation by cleaning out the derivatives
@@ -1418,6 +1445,9 @@ class _TotalJacInfo(object):
         totals = self.J_dict
         if return_format == 'flat_dict':
             for prom_out, output_name in zip(self.prom_of, of):
+
+                dist_resp = self._distributed_resp.get(output_name)
+
                 for prom_in, input_name in zip(self.prom_wrt, wrt):
 
                     if output_name in wrt_meta and output_name != input_name:
@@ -1426,13 +1456,16 @@ class _TotalJacInfo(object):
                         continue
 
                     totals[prom_out, prom_in][:] = _get_subjac(approx_jac[output_name, input_name],
-                                                               prom_out, prom_in, of_idx, wrt_idx)
+                                                               prom_out, prom_in, of_idx, wrt_idx,
+                                                               dist_resp, comm)
 
         elif return_format in ('dict', 'array'):
             for prom_out, output_name in zip(self.prom_of, of):
                 tot = totals[prom_out]
-                for prom_in, input_name in zip(self.prom_wrt, wrt):
 
+                dist_resp = self._distributed_resp.get(output_name)
+
+                for prom_in, input_name in zip(self.prom_wrt, wrt):
                     if output_name in wrt_meta and output_name != input_name:
                         # Special case where we constrain an input, and need derivatives of that
                         # constraint wrt all other inputs.
@@ -1441,10 +1474,12 @@ class _TotalJacInfo(object):
                     if prom_out == prom_in and isinstance(tot[prom_in], dict):
                         rows, cols, data = tot[prom_in]['coo']
                         data[:] = _get_subjac(approx_jac[output_name, input_name],
-                                              prom_out, prom_in, of_idx, wrt_idx)[rows, cols]
+                                              prom_out, prom_in, of_idx, wrt_idx,
+                                              dist_resp, comm)[rows, cols]
                     else:
                         tot[prom_in][:] = _get_subjac(approx_jac[output_name, input_name],
-                                                      prom_out, prom_in, of_idx, wrt_idx)
+                                                      prom_out, prom_in, of_idx, wrt_idx,
+                                                      dist_resp, comm)
         else:
             msg = "Unsupported return format '%s." % return_format
             raise NotImplementedError(msg)
@@ -1588,7 +1623,7 @@ class _TotalJacInfo(object):
             self._recording_iter.pop()
 
 
-def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx):
+def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx, dist_resp, comm):
     """
     Return proper subjacobian based on input/output names and indices.
 
@@ -1604,6 +1639,10 @@ def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx):
         Mapping of promoted output name to indices.
     wrt_idx : dict
         Mapping of promoted input name to indices.
+    dist_resp : None or tuple
+        Tuple containing indices and sizes if this response is distributed.
+    comm : MPI.Comm or <FakeComm>
+        MPI communicator object.
 
     Returns
     -------
@@ -1617,9 +1656,26 @@ def _get_subjac(jac_meta, prom_out, prom_in, of_idx, wrt_idx):
             tot = tot[of_idx[prom_out], :]
         if prom_in in wrt_idx:
             tot = tot[:, wrt_idx[prom_in]]
-        return tot
     else:
-        return jac_meta['value']
+        tot = jac_meta['value']
+
+    if dist_resp:
+        n_wrt = tot.shape[1]
+        tot = tot.flatten()
+        _, sizes = dist_resp
+        n_of_global = np.sum(sizes)
+
+        # Adjust sizes to account for wrt dimension in jacobian.
+        sizes = sizes * n_wrt
+
+        offsets = np.zeros(sizes.size, dtype=INT_DTYPE)
+        offsets[1:] = np.cumsum(sizes[:-1])
+        all_tot = np.zeros(n_of_global * n_wrt)
+
+        comm.Allgatherv(tot, [all_tot, sizes, offsets, MPI.DOUBLE])
+        tot = all_tot.reshape((n_of_global, n_wrt))
+
+    return tot
 
 
 def _check_voi_meta(name, parallel_deriv_color, matmat, simul_coloring):
