@@ -220,6 +220,8 @@ class ScipyOptimizeDriver(Driver):
                     d['total_adder'] = None
                     d['total_scaler'] = None
                     d['size'] = meta['size']
+                    d['global_size'] = meta['global_size']
+                    d['distributed'] = meta['distributed']
                     d['linear'] = True
                     self._cons[name] = d
 
@@ -249,7 +251,7 @@ class ScipyOptimizeDriver(Driver):
         desvar_vals = self.get_design_var_values()
         self._dvlist = list(self._designvars)
 
-        # maxiter and disp get passsed into scipy with all the other options.
+        # maxiter and disp get passed into scipy with all the other options.
         if 'maxiter' not in self.opt_settings:  # lets you override the value in options
             self.opt_settings['maxiter'] = self.options['maxiter']
         self.opt_settings['disp'] = self.options['disp']
@@ -316,7 +318,7 @@ class ScipyOptimizeDriver(Driver):
 
         if opt in _constraint_optimizers:
             for name, meta in self._cons.items():
-                size = meta['size']
+                size = meta['global_size'] if meta['distributed'] else meta['size']
                 upper = meta['upper']
                 lower = meta['lower']
                 equals = meta['equals']
