@@ -14,9 +14,10 @@ import numpy as np
 import openmdao.api as om
 
 from openmdao.test_suite.components.paraboloid import Paraboloid
+from openmdao.test_suite.components.paraboloid_distributed import DistParab
 from openmdao.test_suite.groups.parallel_groups import FanInGrouped
 
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.general_utils import run_driver, printoptions
 
 from openmdao.utils.mpi import MPI
@@ -47,6 +48,34 @@ class ParaboloidArray(om.ExplicitComponent):
         outputs['f_xy'] = (x - 3.0)**2 + x * y + (y + 4.0)**2 - 3.0
 
 
+class ParaboloidDiscrete(om.ExplicitComponent):
+
+    def setup(self):
+        self.add_discrete_input('x', val=10, tags='xx')
+        self.add_discrete_input('y', val=0, tags='yy')
+        self.add_discrete_output('f_xy', val=0, tags='ff')
+
+    def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
+        x = discrete_inputs['x']
+        y = discrete_inputs['y']
+        f_xy = (x - 3.0)**2 + x * y + (y + 4.0)**2 - 3.0
+        discrete_outputs['f_xy'] = int(f_xy)
+
+
+class ParaboloidDiscreteArray(om.ExplicitComponent):
+
+    def setup(self):
+        self.add_discrete_input('x', val=np.ones((2, )), tags='xx')
+        self.add_discrete_input('y', val=np.ones((2, )), tags='yy')
+        self.add_discrete_output('f_xy', val=np.ones((2, )), tags='ff')
+
+    def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
+        x = discrete_inputs['x']
+        y = discrete_inputs['y']
+        f_xy = (x - 3.0)**2 + x * y + (y + 4.0)**2 - 3.0
+        discrete_outputs['f_xy'] = f_xy.astype(np.int)
+
+
 class TestErrors(unittest.TestCase):
 
     def test_generator_check(self):
@@ -469,7 +498,7 @@ class TestDOEDriver(unittest.TestCase):
         for case, expected_case in zip(cases, expected):
             outputs = cr.get_case(case).outputs
             for name in ('x', 'y'):
-                assert_rel_error(self, outputs[name], expected_case[name], 1e-4)
+                assert_near_equal(outputs[name], expected_case[name], 1e-4)
 
     def test_full_factorial(self):
         prob = om.Problem()
@@ -751,8 +780,8 @@ class TestDOEDriver(unittest.TestCase):
             bucket = int((y + y_offset) / (y_bucket_size / samples))
             y_buckets_filled.add(bucket)
 
-            assert_rel_error(self, x, expected_case['x'], 1e-4)
-            assert_rel_error(self, y, expected_case['y'], 1e-4)
+            assert_near_equal(x, expected_case['x'], 1e-4)
+            assert_near_equal(y, expected_case['y'], 1e-4)
 
         self.assertEqual(x_buckets_filled, all_buckets)
         self.assertEqual(y_buckets_filled, all_buckets)
@@ -819,8 +848,8 @@ class TestDOEDriver(unittest.TestCase):
             bucket = int((y + y_offset) / (y_bucket_size / samples))
             y_buckets_filled.add(bucket)
 
-            assert_rel_error(self, x, expected_case['xy'][0], 1e-4)
-            assert_rel_error(self, y, expected_case['xy'][1], 1e-4)
+            assert_near_equal(x, expected_case['xy'][0], 1e-4)
+            assert_near_equal(y, expected_case['xy'][1], 1e-4)
 
         self.assertEqual(x_buckets_filled, all_buckets)
         self.assertEqual(y_buckets_filled, all_buckets)
@@ -912,9 +941,237 @@ class TestDOEDriver(unittest.TestCase):
         final_case = cr.list_cases('driver')[-1]
         outputs = cr.get_case(final_case).outputs
 
-        assert_rel_error(self, outputs['x'], 10.0, 1e-7)
-        assert_rel_error(self, outputs['y'], 20.0, 1e-7)
-        assert_rel_error(self, outputs['z'], 30.0, 1e-7)
+        assert_near_equal(outputs['x'], 10.0, 1e-7)
+        assert_near_equal(outputs['y'], 20.0, 1e-7)
+        assert_near_equal(outputs['z'], 30.0, 1e-7)
+
+    def test_discrete_desvar_list(self):
+        prob = om.Problem()
+        model = prob.model
+
+        # Add independent variables
+        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
+        indeps.add_discrete_output('x', 4)
+        indeps.add_discrete_output('y', 3)
+
+        # Add components
+        model.add_subsystem('parab', ParaboloidDiscrete(), promotes=['*'])
+
+        # Specify design variable range and objective
+        model.add_design_var('x')
+        model.add_design_var('y')
+        model.add_objective('f_xy')
+
+        samples = [[('x', 5), ('y', 1)],
+                   [('x', 3), ('y', 6)],
+                   [('x', -1), ('y', 3)],
+        ]
+
+        # Setup driver for 3 cases at a time
+        prob.driver = om.DOEDriver(om.ListGenerator(samples))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.setup()
+        prob.run_driver()
+        prob.cleanup()
+
+        cr = om.CaseReader("cases.sql")
+        cases = cr.list_cases('driver')
+
+        expected = [{'x': 5, 'y': 1, 'f_xy': 31},
+                    {'x': 3, 'y': 6, 'f_xy': 115},
+                    {'x': -1, 'y': 3, 'f_xy': 59},
+        ]
+        self.assertEqual(len(cases), len(expected))
+
+        for case, expected_case in zip(cases, expected):
+            outputs = cr.get_case(case).outputs
+            for name in ('x', 'y', 'f_xy'):
+                self.assertEqual(outputs[name], expected_case[name])
+                self.assertTrue(isinstance(outputs[name], int))
+
+    def test_discrete_desvar_alltypes(self):
+        # Make sure we can handle any allowed type for discrete variables.
+
+        class PassThrough(om.ExplicitComponent):
+
+            def setup(self):
+                self.add_discrete_input('x', val='abc')
+                self.add_discrete_output('y', val='xyz')
+
+            def compute(self, inputs, outputs, discrete_inputs, discrete_outputs):
+                discrete_outputs['y'] = discrete_inputs['x']
+
+        prob = om.Problem()
+        model = prob.model
+
+        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
+        indeps.add_discrete_output('x', 'abc')
+
+        model.add_subsystem('parab', PassThrough(), promotes=['*'])
+
+        model.add_design_var('x')
+        model.add_constraint('y')
+
+        my_obj = Paraboloid()
+        samples = [[('x', 'abc'), ],
+                   [('x', None), ],
+                   [('x', my_obj, ), ]
+        ]
+
+        prob.driver = om.DOEDriver(om.ListGenerator(samples))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.setup()
+        prob.run_driver()
+        prob.cleanup()
+
+        cr = om.CaseReader("cases.sql")
+        cases = cr.list_cases('driver')
+
+        expected = ['abc', None]
+
+        for case, expected_value in zip(cases, expected):
+            outputs = cr.get_case(case).outputs
+            self.assertEqual(outputs['x'], expected_value)
+
+        # Can't read/write objects through SQL case.
+        self.assertEqual(prob['y'], my_obj)
+
+    def test_discrete_array_output(self):
+        prob = om.Problem()
+        model = prob.model
+
+        # Add independent variables
+        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
+        indeps.add_discrete_output('x', np.ones((2, ), dtype=np.int))
+        indeps.add_discrete_output('y', np.ones((2, ), dtype=np.int))
+
+        # Add components
+        model.add_subsystem('parab', ParaboloidDiscreteArray(), promotes=['*'])
+
+        # Specify design variable range and objective
+        model.add_design_var('x', np.array([5, 1]))
+        model.add_design_var('y', np.array([1, 4]))
+        model.add_objective('f_xy')
+
+        recorder = om.SqliteRecorder("cases.sql")
+        prob.driver.add_recorder(recorder)
+        prob.add_recorder(recorder)
+        prob.recording_options['record_inputs'] = True
+
+        prob.setup()
+        prob.run_driver()
+        prob.record("end")
+        prob.cleanup()
+
+        cr = om.CaseReader("cases.sql")
+        cases = cr.list_cases('problem')
+
+        case = cr.get_case('end')
+        inputs = case.inputs
+        outputs = case.outputs
+        for name in ('x', 'y'):
+            self.assertTrue(isinstance(inputs[name], np.ndarray))
+            self.assertTrue(inputs[name].shape, (2,))
+            self.assertTrue(isinstance(outputs[name], np.ndarray))
+            self.assertTrue(outputs[name].shape, (2,))
+
+    def test_discrete_arraydesvar_list(self):
+        prob = om.Problem()
+        model = prob.model
+
+        # Add independent variables
+        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
+        indeps.add_discrete_output('x', np.ones((2, ), dtype=np.int))
+        indeps.add_discrete_output('y', np.ones((2, ), dtype=np.int))
+
+        # Add components
+        model.add_subsystem('parab', ParaboloidDiscreteArray(), promotes=['*'])
+
+        # Specify design variable range and objective
+        model.add_design_var('x')
+        model.add_design_var('y')
+        model.add_objective('f_xy')
+
+        samples = [[('x', np.array([5, 1])), ('y', np.array([1, 4]))],
+                   [('x', np.array([3, 2])), ('y', np.array([6, -3]))],
+                   [('x', np.array([-1, 0])), ('y', np.array([3, 5]))],
+        ]
+
+        # Setup driver for 3 cases at a time
+        prob.driver = om.DOEDriver(om.ListGenerator(samples))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.setup()
+        prob.run_driver()
+        prob.cleanup()
+
+        cr = om.CaseReader("cases.sql")
+        cases = cr.list_cases('driver')
+
+        expected = [{'x': np.array([5, 1]), 'y': np.array([1, 4]), 'f_xy': np.array([31, 69])},
+                    {'x': np.array([3, 2]), 'y': np.array([6, -3]), 'f_xy': np.array([115, -7])},
+                    {'x': np.array([-1, 0]), 'y': np.array([3, 5]), 'f_xy': np.array([59, 87])},
+        ]
+        self.assertEqual(len(cases), len(expected))
+
+        for case, expected_case in zip(cases, expected):
+            outputs = cr.get_case(case).outputs
+            for name in ('x', 'y', 'f_xy'):
+                self.assertEqual(outputs[name][0], expected_case[name][0])
+                self.assertEqual(outputs[name][1], expected_case[name][1])
+
+
+    def test_discrete_desvar_csv(self):
+        prob = om.Problem()
+        model = prob.model
+
+        # Add independent variables
+        indeps = model.add_subsystem('indeps', om.IndepVarComp(), promotes=['*'])
+        indeps.add_discrete_output('x', 4)
+        indeps.add_discrete_output('y', 3)
+
+        # Add components
+        model.add_subsystem('parab', ParaboloidDiscrete(), promotes=['*'])
+
+        # Specify design variable range and objective
+        model.add_design_var('x')
+        model.add_design_var('y')
+        model.add_objective('f_xy')
+
+        samples = '\n'.join([" x ,   y",
+                             "5,  1",
+                             "3,  6",
+                             "-1,  3",
+                             ])
+
+        # this file contains design variable inputs in CSV format
+        with open('cases.csv', 'w') as f:
+            f.write(samples)
+
+        # Setup driver for 3 cases at a time
+        prob.driver = om.DOEDriver(om.CSVGenerator('cases.csv'))
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.setup()
+        prob.run_driver()
+        prob.cleanup()
+
+        cr = om.CaseReader("cases.sql")
+        cases = cr.list_cases('driver')
+
+        expected = [{'x': 5, 'y': 1, 'f_xy': 31},
+                    {'x': 3, 'y': 6, 'f_xy': 115},
+                    {'x': -1, 'y': 3, 'f_xy': 59},
+        ]
+        self.assertEqual(len(cases), len(expected))
+
+        for case, expected_case in zip(cases, expected):
+            outputs = cr.get_case(case).outputs
+            for name in ('x', 'y', 'f_xy'):
+                self.assertEqual(outputs[name], expected_case[name])
+                self.assertTrue(isinstance(outputs[name], int))
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
@@ -1555,5 +1812,94 @@ class TestParallelDOEFeature2(unittest.TestCase):
                 self.expect_text)
 
 
+@unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
+class TestParallelDistribDOE(unittest.TestCase):
+
+    N_PROCS = 4
+
+    def setUp(self):
+        self.startdir = os.getcwd()
+        self.tempdir = tempfile.mkdtemp(prefix='TestDOEDriver-')
+        os.chdir(self.tempdir)
+
+    def tearDown(self):
+        os.chdir(self.startdir)
+        try:
+            shutil.rmtree(self.tempdir)
+        except OSError:
+            pass
+
+    def test_doe_distributed_var(self):
+        size = 3
+
+        prob = om.Problem()
+        model = prob.model
+
+        ivc = om.IndepVarComp()
+        ivc.add_output('x', np.ones((size, )))
+        ivc.add_output('y', np.ones((size, )))
+        ivc.add_output('a', -3.0 + 0.6 * np.arange(size))
+
+        model.add_subsystem('p', ivc, promotes=['*'])
+        model.add_subsystem("parab", DistParab(arr_size=size, deriv_type='dense'), promotes=['*'])
+        model.add_subsystem('sum', om.ExecComp('f_sum = sum(f_xy)',
+                                               f_sum=np.ones((size, )),
+                                               f_xy=np.ones((size, ))),
+                            promotes=['*'])
+
+        model.add_design_var('x', lower=-50.0, upper=50.0)
+        model.add_design_var('y', lower=-50.0, upper=50.0)
+        model.add_objective('f_xy')
+        model.add_objective('f_sum', index=-1)
+
+        prob.driver = om.DOEDriver(om.FullFactorialGenerator(levels=2))
+        prob.driver.options['run_parallel'] = True
+        prob.driver.options['procs_per_model'] = 2
+
+        prob.driver.add_recorder(om.SqliteRecorder("cases.sql"))
+
+        prob.setup()
+        prob.run_driver()
+        prob.cleanup()
+
+        # check recorded cases from each case file
+        rank = prob.comm.rank
+        if rank == 0:
+            filename0 = "cases.sql_0"
+            values = []
+
+            cr = om.CaseReader(filename0)
+            cases = cr.list_cases('driver')
+            for case in cases:
+                outputs = cr.get_case(case).outputs
+                values.append(outputs)
+
+            # 2**6 cases, half on each rank
+            self.assertEqual(len(values), 32)
+            x_inputs = [list(val['x']) for val in values]
+            for n1 in [-50.]:
+                for n2 in [-50., 50.]:
+                    for n3 in [-50., 50.]:
+                        self.assertEqual(x_inputs.count([n1, n2, n3]), 8)
+
+        elif rank == 1:
+            filename0 = "cases.sql_1"
+            values = []
+
+            cr = om.CaseReader(filename0)
+            cases = cr.list_cases('driver')
+            for case in cases:
+                outputs = cr.get_case(case).outputs
+                values.append(outputs)
+
+            # 2**6 cases, half on each rank
+            self.assertEqual(len(values), 32)
+            x_inputs = [list(val['x']) for val in values]
+            for n1 in [50.]:
+                for n2 in [-50., 50.]:
+                    for n3 in [-50., 50.]:
+                        self.assertEqual(x_inputs.count([n1, n2, n3]), 8)
+
+
 if __name__ == "__main__":
     unittest.main()
