@@ -29,6 +29,18 @@ from openmdao.solvers.solver import Solver
 """
 SQL case database version history.
 ----------------------------------
+10-- OpenMDAO 3.0
+     Added abs_err and rel_err recording to Problem recording
+9 -- OpenMDAO 3.0
+     Changed the character to split the derivatives from 'of,wrt' to 'of!wrt' to allow for commas
+     in variable names
+8 -- OpenMDAO 3.0
+     Added inputs, outputs, and residuals fields to problem_cases table. Added
+     outputs and residuals fields to driver_iterations table
+7 -- OpenMDAO 3.0
+     Added derivatives field to table for recording problems.
+6 -- OpenMDAO 3.X
+     Removed abs2prom from the driver_metadata table.
 5 -- OpenMDAO 2.5
      Added source column (driver name, system/solver pathname) to global iterations table.
 4 -- OpenMDAO 2.4
@@ -40,7 +52,7 @@ SQL case database version history.
 1 -- Through OpenMDAO 2.3
      Original implementation.
 """
-format_version = 5
+format_version = 10
 
 
 def array_to_blob(array):
@@ -187,7 +199,7 @@ class SqliteRecorder(CaseRecorder):
 
                 c.execute("CREATE TABLE driver_iterations(id INTEGER PRIMARY KEY, "
                           "counter INT, iteration_coordinate TEXT, timestamp REAL, "
-                          "success INT, msg TEXT, inputs TEXT, outputs TEXT)")
+                          "success INT, msg TEXT, inputs TEXT, outputs TEXT, residuals TEXT)")
                 c.execute("CREATE TABLE driver_derivatives(id INTEGER PRIMARY KEY, "
                           "counter INT, iteration_coordinate TEXT, timestamp REAL, "
                           "success INT, msg TEXT, derivatives BLOB)")
@@ -195,7 +207,8 @@ class SqliteRecorder(CaseRecorder):
 
                 c.execute("CREATE TABLE problem_cases(id INTEGER PRIMARY KEY, "
                           "counter INT, case_name TEXT, timestamp REAL, "
-                          "success INT, msg TEXT, outputs TEXT)")
+                          "success INT, msg TEXT, inputs TEXT, outputs TEXT, residuals TEXT, "
+                          "jacobian BLOB, abs_err REAL, rel_err REAL)")
                 c.execute("CREATE INDEX prob_name_ind on problem_cases(case_name)")
 
                 c.execute("CREATE TABLE system_iterations(id INTEGER PRIMARY KEY, "
@@ -390,25 +403,28 @@ class SqliteRecorder(CaseRecorder):
         if self.connection:
             outputs = data['output']
             inputs = data['input']
+            residuals = data['residual']
 
             # convert to list so this can be dumped as JSON
-            for in_out in (inputs, outputs):
-                if in_out is None:
+            for in_out_resid in (inputs, outputs, residuals):
+                if in_out_resid is None:
                     continue
-                for var in in_out:
-                    in_out[var] = make_serializable(in_out[var])
+                for var in in_out_resid:
+                    in_out_resid[var] = make_serializable(in_out_resid[var])
 
             outputs_text = json.dumps(outputs)
             inputs_text = json.dumps(inputs)
+            residuals_text = json.dumps(residuals)
 
             with self.connection as c:
                 c = c.cursor()  # need a real cursor for lastrowid
 
                 c.execute("INSERT INTO driver_iterations(counter, iteration_coordinate, "
-                          "timestamp, success, msg, inputs, outputs) VALUES(?,?,?,?,?,?,?)",
+                          "timestamp, success, msg, inputs, outputs, residuals) "
+                          "VALUES(?,?,?,?,?,?,?,?)",
                           (self._counter, self._iteration_coordinate,
                            metadata['timestamp'], metadata['success'], metadata['msg'],
-                           inputs_text, outputs_text))
+                           inputs_text, outputs_text, residuals_text))
 
                 c.execute("INSERT INTO global_iterations(record_type, rowid, source) VALUES(?,?,?)",
                           ('driver', c.lastrowid, recording_requester._get_name()))
@@ -428,22 +444,46 @@ class SqliteRecorder(CaseRecorder):
         """
         if self.connection:
             outputs = data['output']
+            inputs = data['input']
+            residuals = data['residual']
+
+            driver = recording_requester.driver
+            if recording_requester.recording_options['record_derivatives'] and \
+                    driver._designvars and driver._responses:
+                totals = data['totals']
+            else:
+                totals = OrderedDict([])
+            totals_array = dict_to_structured_array(totals)
+            totals_blob = array_to_blob(totals_array)
 
             # convert to list so this can be dumped as JSON
-            if outputs is not None:
-                for var in outputs:
-                    outputs[var] = make_serializable(outputs[var])
+            for in_out_resid in (inputs, outputs, residuals):
+                if in_out_resid is None:
+                    continue
+                for var in in_out_resid:
+                    in_out_resid[var] = make_serializable(in_out_resid[var])
 
             outputs_text = json.dumps(outputs)
+            inputs_text = json.dumps(inputs)
+            residuals_text = json.dumps(residuals)
+
+            abs_err = data['abs']
+            rel_err = data['rel']
 
             with self.connection as c:
                 c = c.cursor()  # need a real cursor for lastrowid
 
                 c.execute("INSERT INTO problem_cases(counter, case_name, "
-                          "timestamp, success, msg, outputs) VALUES(?,?,?,?,?,?)",
+                          "timestamp, success, msg, inputs, outputs, residuals, jacobian, "
+                          "abs_err, rel_err ) "
+                          "VALUES(?,?,?,?,?,?,?,?,?,?,?)",
                           (self._counter, metadata['name'],
                            metadata['timestamp'], metadata['success'], metadata['msg'],
-                           outputs_text))
+                           inputs_text, outputs_text, residuals_text, totals_blob,
+                           abs_err, rel_err))
+
+                c.execute("INSERT INTO global_iterations(record_type, rowid, source) VALUES(?,?,?)",
+                          ('problem', c.lastrowid, metadata['name']))
 
     def record_iteration_system(self, recording_requester, data, metadata):
         """
@@ -674,3 +714,18 @@ class SqliteRecorder(CaseRecorder):
         # close database connection
         if self.connection:
             self.connection.close()
+
+    def delete_recordings(self):
+        """
+        Delete all the recordings.
+        """
+        if self.connection:
+            self.connection.execute("DELETE FROM global_iterations")
+            self.connection.execute("DELETE FROM driver_iterations")
+            self.connection.execute("DELETE FROM driver_derivatives")
+            self.connection.execute("DELETE FROM problem_cases")
+            self.connection.execute("DELETE FROM system_iterations")
+            self.connection.execute("DELETE FROM solver_iterations")
+            self.connection.execute("DELETE FROM driver_metadata")
+            self.connection.execute("DELETE FROM system_metadata")
+            self.connection.execute("DELETE FROM solver_metadata")
