@@ -7,7 +7,7 @@ import numpy as np
 import openmdao.api as om
 from openmdao.test_suite.components.ae_tests import AEComp, AEDriver
 from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, SellarDis2withDerivatives
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.mpi import MPI
 
 try:
@@ -47,8 +47,8 @@ class TestNLBlockJacobi(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['y1'], 25.58830273, .00001)
-        assert_rel_error(self, prob['y2'], 12.05848819, .00001)
+        assert_near_equal(prob['y1'], 25.58830273, .00001)
+        assert_near_equal(prob['y2'], 12.05848819, .00001)
 
     def test_feature_maxiter(self):
         import numpy as np
@@ -81,8 +81,8 @@ class TestNLBlockJacobi(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['y1'], 25.5723813937, .00001)
-        assert_rel_error(self, prob['y2'], 12.0542542372, .00001)
+        assert_near_equal(prob['y1'], 25.5723813937, .00001)
+        assert_near_equal(prob['y2'], 12.0542542372, .00001)
 
     def test_feature_rtol(self):
         import numpy as np
@@ -115,8 +115,8 @@ class TestNLBlockJacobi(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['y1'], 25.5891491526, .00001)
-        assert_rel_error(self, prob['y2'], 12.0569142166, .00001)
+        assert_near_equal(prob['y1'], 25.5891491526, .00001)
+        assert_near_equal(prob['y2'], 12.0569142166, .00001)
 
     def test_feature_atol(self):
         import numpy as np
@@ -149,8 +149,8 @@ class TestNLBlockJacobi(unittest.TestCase):
 
         prob.run_model()
 
-        assert_rel_error(self, prob['y1'], 25.5886171567, .00001)
-        assert_rel_error(self, prob['y2'], 12.05848819, .00001)
+        assert_near_equal(prob['y1'], 25.5886171567, .00001)
+        assert_near_equal(prob['y2'], 12.05848819, .00001)
 
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
