@@ -3,7 +3,7 @@ import unittest
 import numpy as np
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_rel_error
+from openmdao.utils.assert_utils import assert_near_equal
 
 
 class TestNonlinearCircuit(unittest.TestCase):
@@ -141,14 +141,14 @@ class TestNonlinearCircuit(unittest.TestCase):
 
         p.run_model()
 
-        assert_rel_error(self, p['circuit.n1.V'], 9.90804735, 1e-5)
-        assert_rel_error(self, p['circuit.n2.V'], 0.71278185, 1e-5)
-        assert_rel_error(self, p['circuit.R1.I'], 0.09908047, 1e-5)
-        assert_rel_error(self, p['circuit.R2.I'], 0.00091953, 1e-5)
-        assert_rel_error(self, p['circuit.D1.I'], 0.00091953, 1e-5)
+        assert_near_equal(p['circuit.n1.V'], 9.90804735, 1e-5)
+        assert_near_equal(p['circuit.n2.V'], 0.71278185, 1e-5)
+        assert_near_equal(p['circuit.R1.I'], 0.09908047, 1e-5)
+        assert_near_equal(p['circuit.R2.I'], 0.00091953, 1e-5)
+        assert_near_equal(p['circuit.D1.I'], 0.00091953, 1e-5)
 
         # sanity check: should sum to .1 Amps
-        assert_rel_error(self, p['circuit.R1.I'] + p['circuit.D1.I'], .1, 1e-6)
+        assert_near_equal(p['circuit.R1.I'] + p['circuit.D1.I'], .1, 1e-6)
 
 
 if __name__ == "__main__":
