@@ -21,6 +21,8 @@ from openmdao.utils.general_utils import warn_deprecation
 # pylint: disable=E0611, F0401
 from math import floor, pi
 
+import numpy as np
+
 
 ####################################
 # Class Definitions
@@ -1052,6 +1054,36 @@ def convert_units(val, old_units, new_units=None):
     return (val + offset) * factor
 
 
+def _has_val_mismatch(units1, val1, units2, val2):
+    """
+    Return True if values differ after unit conversion or if values differ when units are None.
+
+    Parameters
+    ----------
+    units1 : str or None
+        Units for first value.
+    val1 : float or ndarray
+        First value.
+    units2 : str or None
+        Units for second value.
+    val2 : float or ndarray
+        Second value.
+    """
+    if units1 != units2:
+        if units1 is None or units2 is None:
+            return True
+
+        # convert units
+        val1 = convert_units(val1, units1, new_units=units2)
+
+    rtol = 1e-10
+    norm1 = np.linalg.norm(val1)
+    if norm1 == 0.:
+        return np.linalg.norm(val2) > rtol
+    else:
+        return np.linalg.norm(val2 - val1) / norm1 > rtol
+
+
 # Load in the default unit library
 file_path = open(os.path.join(os.path.dirname(__file__), 'unit_library.ini'))
 with file_path as default_lib:
