@@ -74,11 +74,17 @@ class NodeInfo {
         ];
 
         this.abs2prom = abs2prom;
-        this.table = d3.select('#node-info-container');
+        this.table = d3.select('#node-info-table');
+        this.container = d3.select('#node-info-container');
         this.thead = this.table.select('thead');
         this.tbody = this.table.select('tbody');
         this.toolbarButton = d3.select('#info-button');
         this.hidden = true;
+        this.pinned = false;
+
+        const self = this;
+        this.pinButton = d3.select('#node-info-pin')
+            .on('click', e => { self.unpin(); })
     }
 
     /** Make the info box visible if it's hidden */
@@ -101,6 +107,22 @@ class NodeInfo {
         else this.hide();
     }
 
+    pin() { 
+        this.pinned = true;
+        this.pinButton.attr('class', 'info-visible');
+    }
+    
+    unpin() {
+        this.pinned = false;
+        this.pinButton.attr('class', 'info-hidden');
+        this.clear();
+    }
+
+    togglePin() {
+        if (this.pinned) this.unpin();
+        else this.pin();
+    }
+
     _addPropertyRow(label, val, capitalize = false) {
         const newRow = this.tbody.append('tr');
 
@@ -122,7 +144,9 @@ class NodeInfo {
      * @param {N2TreeNode} color The color to make the title bar.
      */
     update(event, obj, color = '#42926b') {
-        if (this.hidden) return;
+        if (this.hidden || this.pinned) return;
+
+        this.clear();
         // Put the name in the title
         this.table.select('thead th')
             .style('background-color', color)
@@ -153,16 +177,20 @@ class NodeInfo {
             .style('height', this.table.node().scrollHeight + 'px')
 
         this.move(event);
-        this.table.attr('class', 'info-visible');
+        this.container.attr('class', 'info-visible');
     }
 
     /** Wipe the contents of the table body */
     clear() {
-        if (this.hidden) return;
-        this.table
+        if (this.hidden || this.pinned) return;
+        this.container
             .attr('class', 'info-hidden')
             .style('width', 'auto')
-            .style('height', 'auto')
+            .style('height', 'auto');
+
+        this.table
+            .style('width', 'auto')
+            .style('height', 'auto');
 
         this.tbody.html('');
     }
@@ -172,29 +200,29 @@ class NodeInfo {
      * @param {Object} event The triggering event containing the position.
      */
     move(event) {
-        if (this.hidden) return;
+        if (this.hidden || this.pinned) return;
         const offset = 30;
 
         // Mouse is in left half of window, put box to right of mouse
         if (event.clientX < window.innerWidth / 2) {
-            this.table.style('right', 'auto');
-            this.table.style('left', (event.clientX + offset) + 'px')
+            this.container.style('right', 'auto');
+            this.container.style('left', (event.clientX + offset) + 'px')
         }
         // Mouse is in right half of window, put box to left of mouse
         else {
-            this.table.style('left', 'auto');
-            this.table.style('right', (window.innerWidth - event.clientX + offset) + 'px')
+            this.container.style('left', 'auto');
+            this.container.style('right', (window.innerWidth - event.clientX + offset) + 'px')
         }
 
         // Mouse is in top half of window, put box below mouse
         if (event.clientY < window.innerHeight / 2) {
-            this.table.style('bottom', 'auto');
-            this.table.style('top', (event.clientY - offset) + 'px')
+            this.container.style('bottom', 'auto');
+            this.container.style('top', (event.clientY - offset) + 'px')
         }
         // Mouse is in bottom half of window, put box above mouse
         else {
-            this.table.style('top', 'auto');
-            this.table.style('bottom', (window.innerHeight - event.clientY - offset) + 'px')
+            this.container.style('top', 'auto');
+            this.container.style('bottom', (window.innerHeight - event.clientY - offset) + 'px')
         }
     }
 }
@@ -233,13 +261,13 @@ class N2UserInterface {
 
         this._setupCollapseDepthElement();
         this.updateClickedIndices();
-
-        d3.select('#searchButtonId')
-            .on('click', this.searchButtonClicked.bind(this));
         this._setupSearch();
+        this._setupResizerDrag();
+        this._setupWindowResizer();
 
         this.legend = new N2Legend(this.n2Diag.modelData);
         this.nodeInfoBox = new NodeInfo(this.n2Diag.model.abs2prom);
+        this.toolbar = new N2Toolbar(this);
     }
 
     /** Set up the menu for selecting an arbitrary depth to collapse to. */
@@ -259,21 +287,139 @@ class N2UserInterface {
         };
     }
 
+    /** Set up event handlers for grabbing the bottom corner and dragging */
+    _setupResizerDrag() {
+        const handle = d3.select('#n2-resizer-handle');
+        const box = d3.select('#n2-resizer-box');
+        const body = d3.select('body');
+
+        handle.on('mousedown', e => {
+            box
+                .style('top', n2Diag.layout.gapSpace)
+                .style('bottom', n2Diag.layout.gapSpace);
+
+            handle.attr('class', 'active-resizer-handle');
+            box.attr('class', 'active-resizer-box');
+
+            const startPos = {
+                'x': d3.event.clientX,
+                'y': d3.event.clientY
+            };
+            const startDims = {
+                'width': parseInt(box.style('width')),
+                'height': parseInt(box.style('height'))
+            };
+            const offset = {
+                'x': startPos.x - startDims.width,
+                'y': startPos.y - startDims.height
+            };
+            let newDims = {
+                'x': startDims.width,
+                'y': startDims.height
+            };
+
+            handle.html(Math.round(newDims.x) + ' x ' + newDims.y);
+
+            body.style('cursor', 'nwse-resize')
+                .on('mouseup', e => {
+                    n2Diag.manuallyResized = true;
+
+                    // Update the slider value and display
+                    const defaultHeight = window.innerHeight * .95;
+                    const newPercent = Math.round((newDims.y / defaultHeight) * 100);
+                    d3.select('#model-slider').node().value = newPercent;
+                    d3.select('#model-slider-label').html(newPercent + "%");
+
+                    // Perform the actual resize
+                    n2Diag.verticalResize(newDims.y);
+
+                    box.style('width', null).style('height', null);
+
+                    // Turn off the resizing box border and handle
+                    handle.attr('class', 'inactive-resizer-handle');
+                    box.attr('class', 'inactive-resizer-box');
+
+                    // Get rid of the drag event handlers
+                    body.style('cursor', 'default')
+                        .on('mousemove', null)
+                        .on('mouseup', null);
+                })
+                .on('mousemove', e => {
+                    const newHeight = d3.event.clientY - offset.y;
+                    if (newHeight + n2Diag.layout.gapDist * 2 >= window.innerHeight * .5) {
+                        newDims = {
+                            'x': d3.event.clientX - offset.x,
+                            'y': newHeight
+                        };
+
+                        // Maintain the ratio by only resizing in the least moved direction
+                        // and resizing the other direction by a fraction of that
+                        if (newDims.x < newDims.y) {
+                            newDims.y = n2Diag.layout.calcHeightBasedOnNewWidth(newDims.x);
+                        }
+                        else {
+                            newDims.x = n2Diag.layout.calcWidthBasedOnNewHeight(newDims.y);
+                        }
+
+                        box
+                            .style('width', newDims.x + 'px')
+                            .style('height', newDims.y + 'px');
+
+                        handle.html(Math.round(newDims.x) + ' x ' + newDims.y);
+                    }
+                });
+
+            d3.event.preventDefault();
+        });
+
+    }
+
+    /** Respond to window resize events if the diagram hasn't been manually sized */
+    _setupWindowResizer() {
+        const self = this;
+        const n2Diag = self.n2Diag;
+        this.pixelRatio = window.devicePixelRatio;
+
+        self.resizeTimeout = null;
+        d3.select(window).on('resize', function () {
+            const newPixelRatio = window.devicePixelRatio;
+
+            // If the browser window itself is zoomed, don't do anything
+            if (newPixelRatio != self.pixelRatio) {
+                self.pixelRatio = newPixelRatio;
+                return;
+            }
+
+            if (!n2Diag.manuallyResized) {
+                clearTimeout(self.resizeTimeout);
+                self.resizeTimeout =
+                    setTimeout(function () {
+                        n2Diag.verticalResize(window.innerHeight * .95);
+                    }, 200);
+            }
+        })
+    }
+
+    /**
+     * Make sure the clicked node is deeper than the zoomed node, that
+     * it's not the root node, and that it actually has children.
+     * @param {N2TreeNode} node The right-clicked node to check.
+     */
+    isCollapsible(node) {
+        return (node.depth > this.n2Diag.zoomedElement.depth &&
+            node.type !== 'root' && node.hasChildren());
+    }
+
     /**
      * When a node is right-clicked or otherwise targeted for collapse, make sure it
-     * has children and isn't the root node. Set the node as minimized and update
-     * the diagram drawing.
+     * it's allowed, then set the node as minimized and update the diagram drawing.
      */
     collapse() {
         testThis(this, 'N2UserInterface', 'collapse');
 
-        let node = this.leftClickedNode;
+        let node = this.rightClickedNode;
 
-        if (!node.hasChildren()) return;
-
-        // Don't allow minimizing of root node
-        if (node.depth > this.n2Diag.zoomedElement.depth || node.type !== 'root') {
-            this.rightClickedNode = node;
+        if (this.isCollapsible(node)) {
 
             if (this.collapsedRightClickNode !== undefined) {
                 this.rightClickedNode = this.collapsedRightClickNode;
@@ -290,23 +436,29 @@ class N2UserInterface {
         }
     }
 
-    /* When a node is right-clicked, collapse it. */
-    rightClick(node1, node2) {
+    /**
+     * When a node is right-clicked, collapse it if it's allowed.
+     * @param {N2TreeNode} node The node that was right-clicked.
+     */
+    rightClick(node) {
         testThis(this, 'N2UserInterface', 'rightClick');
 
-        this.leftClickedNode = node1;
-        this.rightClickedNode = node2;
-
-        let node = this.leftClickedNode;
-        node['collapsable'] = true;
-
-        this.backButtonHistory.push({
-            node: node,
-        });
-
         d3.event.preventDefault();
         d3.event.stopPropagation();
-        this.collapse();
+
+        if (node.isMinimized) {
+            this.rightClickedNode = node;
+            this.addBackButtonHistory();
+            this._uncollapse(node);
+            this.n2Diag.update();
+        }
+        else if (this.isCollapsible(node)) {
+            this.rightClickedNode = node;
+            node.collapsable = true;
+
+            this.addBackButtonHistory();
+            this.collapse();
+        }
     }
 
     /**
@@ -319,7 +471,8 @@ class N2UserInterface {
         this.lastClickWasLeft = true;
         if (this.leftClickedNode.depth > this.n2Diag.zoomedElement.depth) {
             this.leftClickIsForward = true; // forward
-        } else if (this.leftClickedNode.depth < this.n2Diag.zoomedElement.depth) {
+        }
+        else if (this.leftClickedNode.depth < this.n2Diag.zoomedElement.depth) {
             this.leftClickIsForward = false; // backwards
         }
         this.n2Diag.updateZoomedElement(node);
@@ -332,16 +485,14 @@ class N2UserInterface {
      */
     leftClick(node) {
         testThis(this, 'N2UserInterface', 'leftClick');
+        d3.event.preventDefault();
+        d3.event.stopPropagation();
 
         if (!node.hasChildren() || node.isParam()) return;
         if (d3.event.button != 0) return;
-        this.backButtonHistory.push({
-            node: this.n2Diag.zoomedElement,
-        });
-        this.forwardButtonHistory = [];
+        this.addBackButtonHistory();
         this._setupLeftClick(node);
-        d3.event.preventDefault();
-        d3.event.stopPropagation();
+
         this.n2Diag.update();
     }
 
@@ -364,6 +515,37 @@ class N2UserInterface {
         }
     }
 
+    /**
+     * Preserve the current zoomed element and state of all hidden elements.
+     * @param {Boolean} clearForward If true, erase the forward history.
+     */
+    addBackButtonHistory(clearForward = true) {
+        let formerHidden = [];
+        this.n2Diag.findAllHidden(formerHidden, false);
+
+        this.backButtonHistory.push({
+            'node': this.n2Diag.zoomedElement,
+            'hidden': formerHidden
+        });
+
+        if (clearForward) this.forwardButtonHistory = [];
+    }
+
+    /**
+     * Preserve the specified node as the zoomed element,
+     * and remember the state of all hidden elements.
+     * @param {N2TreeNode} node The node to preserve as the zoomed element.
+     */
+    addForwardButtonHistory(node) {
+        let formerHidden = [];
+        this.n2Diag.findAllHidden(formerHidden, true);
+
+        this.forwardButtonHistory.push({
+            'node': node,
+            'hidden': formerHidden
+        });
+    }
+
     /**
      * When the back history button is clicked, pop the top node from that
      * history stack, and disable the button if the stack is empty. Find the
@@ -373,16 +555,21 @@ class N2UserInterface {
     backButtonPressed() {
         testThis(this, 'N2UserInterface', 'backButtonPressed');
 
-        if (this.backButtonHistory.length == 0) return;
+        if (this.backButtonHistory.length == 0) {
+            debugInfo("backButtonPressed(): no items in history");
+            return;
+        }
 
-        let node = this.backButtonHistory[this.backButtonHistory.length - 1].node;
+        debugInfo("backButtonPressed(): " +
+            this.backButtonHistory.length + " items in history");
+
+        const history = this.backButtonHistory.pop();
+        const node = history.node;
 
         // Check to see if the node is a collapsed node or not
         if (node.collapsable) {
             this.leftClickedNode = node;
-            this.forwardButtonHistory.push({
-                node: this.leftClickedNode,
-            });
+            this.addForwardButtonHistory(node);
             this.collapse();
         }
         else {
@@ -391,13 +578,11 @@ class N2UserInterface {
                 if (obj.isMinimized) return;
             }
 
-            this.forwardButtonHistory.push({
-                node: this.n2Diag.zoomedElement,
-            });
+            this.addForwardButtonHistory(this.n2Diag.zoomedElement);
             this._setupLeftClick(node);
         }
 
-        this.backButtonHistory.pop();
+        this.n2Diag.resetAllHidden(history.hidden);
         this.n2Diag.update();
     }
 
@@ -410,19 +595,29 @@ class N2UserInterface {
     forwardButtonPressed() {
         testThis(this, 'N2UserInterface', 'forwardButtonPressed');
 
-        if (this.forwardButtonHistory.length == 0) return;
-        let node = this.forwardButtonHistory.pop().node;
-        d3.select('#forwardButtonId').attr('disabled',
+        if (this.forwardButtonHistory.length == 0) {
+            debugInfo("forwardButtonPressed(): no items in history");
+            return;
+        }
+
+        debugInfo("forwardButtonPressed(): " +
+            this.forwardButtonHistory.length + " items in history");
+
+        const history = this.forwardButtonHistory.pop();
+        const node = history.node;
+
+        d3.select('#redo-graph').classed('disabled-button',
             (this.forwardButtonHistory.length == 0));
 
         for (let obj = node; obj != null; obj = obj.parent) {
             // make sure history item is not minimized
             if (obj.isMinimized) return;
         }
-        this.backButtonHistory.push({
-            node: this.n2Diag.zoomedElement,
-        });
+
+        this.addBackButtonHistory(false);
         this._setupLeftClick(node);
+
+        this.n2Diag.resetAllHidden(history.hidden);
         this.n2Diag.update();
     }
 
@@ -468,13 +663,9 @@ class N2UserInterface {
     homeButtonClick() {
         testThis(this, 'N2UserInterface', 'homeButtonClick');
 
-        this.backButtonHistory.push({
-            node: this.n2Diag.zoomedElement,
-        });
-        this.forwardButtonHistory = [];
+        this.addBackButtonHistory();
         this._setupLeftClick(this.n2Diag.model.root);
         this.uncollapseButtonClick(this.n2Diag.model.root);
-        this.n2Diag.update();
     }
 
     /**
@@ -499,6 +690,7 @@ class N2UserInterface {
     collapseOutputsButtonClick(startNode) {
         testThis(this, 'N2UserInterface', 'collapseOutputsButtonClick');
 
+        this.addBackButtonHistory();
         this.findRootOfChangeFunction = this.findRootOfChangeForCollapseUncollapseOutputs;
         N2TransitionDefaults.duration = N2TransitionDefaults.durationSlow;
         this.lastClickWasLeft = false;
@@ -507,13 +699,12 @@ class N2UserInterface {
     }
 
     /**
-     * Mark this node and all of its children as unminimized
+     * Mark this node and all of its children as unminimized/unhidden
      * @param {N2TreeNode} node The node to operate on.
      */
     _uncollapse(node) {
-        if (!node.isParam()) {
-            node.isMinimized = false;
-        }
+        node.isMinimized = false;
+        node.varIsHidden = false;
 
         if (node.hasChildren()) {
             for (let child of node.children) {
@@ -529,6 +720,7 @@ class N2UserInterface {
     uncollapseButtonClick(startNode) {
         testThis(this, 'N2UserInterface', 'uncollapseButtonClick');
 
+        this.addBackButtonHistory();
         this.findRootOfChangeFunction = this.findRootOfChangeForCollapseUncollapseOutputs;
         N2TransitionDefaults.duration = N2TransitionDefaults.durationSlow;
         this.lastClickWasLeft = false;
@@ -562,6 +754,7 @@ class N2UserInterface {
     collapseToDepthSelectChange(newChosenCollapseDepth) {
         testThis(this, 'N2UserInterface', 'collapseToDepthSelectChange');
 
+        this.addBackButtonHistory();
         this.n2Diag.chosenCollapseDepth = newChosenCollapseDepth;
         if (this.n2Diag.chosenCollapseDepth > this.n2Diag.zoomedElement.depth) {
             this._collapseToDepth(
@@ -614,7 +807,7 @@ class N2UserInterface {
         testThis(this, 'N2UserInterface', 'toggleNodeData');
 
         const infoButton = d3.select('#info-button');
-        const nodeData = d3.select('#node-info-container');
+        const nodeData = d3.select('#node-info-table');
 
         if (nodeData.classed('info-hidden')) {
             nodeData.attr('class', 'info-visible');
@@ -648,18 +841,16 @@ class N2UserInterface {
     update() {
         testThis(this, 'N2UserInterface', 'update');
 
-        d3.select('#undo-graph').attr('disabled',
+        d3.select('#undo-graph').classed('disabled-button',
             (this.backButtonHistory.length == 0));
-        d3.select('#redo-graph').attr('disabled',
+        d3.select('#redo-graph').classed('disabled-button',
             (this.forwardButtonHistory.length == 0));
-        d3.select('#reset-graph').attr('disabled',
-            (this.n2Diag.zoomedElement === this.n2Diag.model.root));
     }
 
     /** Called when the search button is actually or effectively clicked to start a search. */
     searchButtonClicked() {
         testThis(this, 'N2UserInterface', 'searchButtonClicked');
-
+        this.addBackButtonHistory();
         this.n2Diag.search.performSearch();
 
         this.findRootOfChangeFunction = this.n2Diag.search.findRootOfChangeForSearch;
